@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/comments.php,v 1.31.2.43 2006/01/17 06:46:26 rlpowell Exp $
+// $Header: /cvsroot/tikiwiki/tiki/comments.php,v 1.31.2.50 2007/05/11 23:15:50 sylvieg Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -161,6 +161,11 @@ $in_reply_to = '';
 if ( ($tiki_p_post_comments == 'y' && (!isset($forum_mode) || $forum_mode == 'n'))
 	|| ($tiki_p_forum_post == 'y' && isset($forum_mode) && $forum_mode == 'y') ) {
     if (isset($_REQUEST["comments_postComment"])) {
+	  if (empty($user) && $feature_antibot == 'y' && (!isset($_SESSION['random_number']) || $_SESSION['random_number'] != $_REQUEST['antibotcode'])) {
+			$smarty->assign('msg',tra("You have mistyped the anti-bot verification code; please try again."));
+			$smarty->display("error.tpl");
+			die;
+		}
 	$comments_show = 'y';
 
 	if ((!empty($_REQUEST["comments_title"])) && (!empty($_REQUEST["comments_data"]))) {
@@ -190,7 +195,6 @@ if ( ($tiki_p_post_comments == 'y' && (!isset($forum_mode) || $forum_mode == 'n'
 		} else {
 		    $parent_id = $_REQUEST["comments_parentId"];
 		}
-
 		$qId = $commentslib->post_new_comment($comments_objectId, $parent_id,
 			$user,
 			$_REQUEST["comments_title"],
@@ -283,6 +287,10 @@ if ( ($tiki_p_post_comments == 'y' && (!isset($forum_mode) || $forum_mode == 'n'
 	    die;
 	}
     }
+} elseif (isset($_REQUEST['comments_postComment'])) {
+	$smarty->assign('msg', tra("You do not have permission to use this feature"));
+	$smarty->display("error.tpl");
+    die;
 }
 
 if ($tiki_p_vote_comments == 'y') {
@@ -442,7 +450,11 @@ $comments_coms = $commentslib->get_comments($comments_objectId, $_REQUEST["comme
 	$comments_offset, $_REQUEST["comments_maxComments"], $_REQUEST["comments_sort_mode"], $_REQUEST["comments_commentFind"],
 	$_REQUEST['comments_threshold'], $_REQUEST["comments_style"], $threadId_if_reply);
 
-$comments_cant = $commentslib->count_comments($comments_objectId);
+if ($comments_prefix_var == 'forum:') {
+	$comments_cant = $commentslib->count_comments('topic:'. $_REQUEST['comments_parentId']); // comments in the topic not in the forum
+} else {
+	$comments_cant = $commentslib->count_comments($comments_objectId);
+}
 $comments_cant_page = $comments_coms['cant'];
 
 $smarty->assign('comments_below', $comments_coms["below"]);
