@@ -107,7 +107,7 @@ INSERT INTO tiki_preferences VALUES ('feature_featuredLinks','y');
 INSERT INTO tiki_preferences VALUES ('feature_file_galleries_comments','n');
 INSERT INTO tiki_preferences VALUES ('feature_file_galleries','n');
 INSERT INTO tiki_preferences VALUES ('feature_file_galleries_rankings','n');
-INSERT INTO tiki_preferences VALUES ('feature_forum_parse','n');
+INSERT INTO tiki_preferences VALUES ('feature_forum_parse','y');
 INSERT INTO tiki_preferences VALUES ('feature_forum_quickjump','n');
 INSERT INTO tiki_preferences VALUES ('feature_forum_rankings','y');
 INSERT INTO tiki_preferences VALUES ('feature_forums','n');
@@ -127,7 +127,7 @@ INSERT INTO tiki_preferences VALUES ('feature_likePages','y');
 INSERT INTO tiki_preferences VALUES ('feature_listPages','y');
 INSERT INTO tiki_preferences VALUES ('feature_live_support','n');
 INSERT INTO tiki_preferences VALUES ('feature_maps','n');
-INSERT INTO tiki_preferences VALUES ('feature_menusfolderstyle','n');
+INSERT INTO tiki_preferences VALUES ('feature_menusfolderstyle','y');
 INSERT INTO tiki_preferences VALUES ('feature_messages','n');
 INSERT INTO tiki_preferences VALUES ('feature_minical','n');
 INSERT INTO tiki_preferences VALUES ('feature_modulecontrols','y');
@@ -202,8 +202,8 @@ INSERT INTO tiki_preferences VALUES ('forgotPass','n');
 INSERT INTO tiki_preferences VALUES ('forum_list_desc','y');
 INSERT INTO tiki_preferences VALUES ('forum_list_lastpost','y');
 INSERT INTO tiki_preferences VALUES ('forum_list_posts','y');
-INSERT INTO tiki_preferences VALUES ('forum_list_ppd','y');
-INSERT INTO tiki_preferences VALUES ('forum_list_topics','y');
+INSERT INTO tiki_preferences VALUES ('forum_list_ppd','n');
+INSERT INTO tiki_preferences VALUES ('forum_list_topics','n');
 INSERT INTO tiki_preferences VALUES ('forum_list_visits','y');
 INSERT INTO tiki_preferences VALUES ('forums_ordering','created_desc');
 INSERT INTO tiki_preferences VALUES ('gal_list_created','y');
@@ -237,7 +237,7 @@ INSERT INTO tiki_preferences VALUES ('long_date_format','%A %d of %B, %Y');
 INSERT INTO tiki_preferences VALUES ('long_time_format','%H:%M:%S %Z');
 INSERT INTO tiki_preferences VALUES ('map_path','/var/www/html/map/');
 INSERT INTO tiki_preferences VALUES ('maxArticles','10');
-INSERT INTO tiki_preferences VALUES ('maxRecords','10');
+INSERT INTO tiki_preferences VALUES ('maxRecords','25');
 INSERT INTO tiki_preferences VALUES ('max_rss_directories','10');
 INSERT INTO tiki_preferences VALUES ('max_rss_articles','10');
 INSERT INTO tiki_preferences VALUES ('max_rss_blog','10');
@@ -252,7 +252,7 @@ INSERT INTO tiki_preferences VALUES ('max_rss_mapfiles','10');
 INSERT INTO tiki_preferences VALUES ('max_rss_wiki','10');
 INSERT INTO tiki_preferences VALUES ('maxVersions','0');
 INSERT INTO tiki_preferences VALUES ('min_pass_length','1');
-INSERT INTO tiki_preferences VALUES ('modallgroups','y');
+INSERT INTO tiki_preferences VALUES ('modallgroups','n');
 INSERT INTO tiki_preferences VALUES ('pass_chr_num','n');
 INSERT INTO tiki_preferences VALUES ('pass_due','999');
 INSERT INTO tiki_preferences VALUES ('poll_comments_default_ordering','points_desc');
