@@ -97,7 +97,7 @@ class ArtLib extends TikiLib {
 	function replace_submission($title, $authorName, $topicId, $useImage, $imgname, $imgsize, 
 	$imgtype, $imgdata, $heading, $body, $publishDate, $expireDate, $user, $subId, $image_x, $image_y, $type, 
 	$topline, $subtitle, $linkto, $image_caption, $lang, $rating = 0, $isfloat = 'n') {
-		global $smarty;
+		global $smarty, $tiki_p_autoapprove_submission;
 		global $tikilib;
 		global $dbTiki;
 		global $sender_email;
@@ -162,25 +162,25 @@ class ArtLib extends TikiLib {
 			$id = $this->getOne($query, array( (int) $now, $title, $hash ) );
 		}
 
-		$emails = $notificationlib->get_mail_events('article_submitted', '*');
-		if (!isset($_SERVER["SERVER_NAME"])) {
-			$_SERVER["SERVER_NAME"] = $_SERVER["HTTP_HOST"];
-		}
-		if (count($emails)) {
-			include_once("lib/notifications/notificationemaillib.php");
-			$foo = parse_url($_SERVER["REQUEST_URI"]);
-			$machine = $tikilib->httpPrefix(). $foo["path"];
-
-			$smarty->assign('mail_site', $_SERVER["SERVER_NAME"]);
-
-			$smarty->assign('mail_user', $user);
-			$smarty->assign('mail_title', $title);
-			$smarty->assign('mail_heading', $heading);
-			$smarty->assign('mail_body', $body);
-			$smarty->assign('mail_date', date("U"));
-			$smarty->assign('mail_machine', $machine);
-			$smarty->assign('mail_subId', $id);
-			sendEmailNotification($emails, "email", "submission_notification_subject.tpl", $_SERVER["SERVER_NAME"], "submission_notification.tpl");
+		if ($tiki_p_autoapprove_submission != 'y') {
+			$emails = $notificationlib->get_mail_events('article_submitted', '*');
+			if (count($emails)) {
+				if (!isset($_SERVER["SERVER_NAME"])) {
+					$_SERVER["SERVER_NAME"] = $_SERVER["HTTP_HOST"];
+				}
+				include_once("lib/notifications/notificationemaillib.php");
+				$foo = parse_url($_SERVER["REQUEST_URI"]);
+				$machine = $tikilib->httpPrefix(). $foo["path"];
+				$smarty->assign('mail_site', $_SERVER["SERVER_NAME"]);
+				$smarty->assign('mail_user', $user);
+				$smarty->assign('mail_title', $title);
+				$smarty->assign('mail_heading', $heading);
+				$smarty->assign('mail_body', $body);
+				$smarty->assign('mail_date', date("U"));
+				$smarty->assign('mail_machine', $machine);
+				$smarty->assign('mail_subId', $id);
+				sendEmailNotification($emails, "email", "submission_notification_subject.tpl", $_SERVER["SERVER_NAME"], "submission_notification.tpl");
+			}
 		}
 
 		return $id;
