@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/lib/imagegals/imagegallib.php,v 1.45.2.39 2006/08/10 10:04:31 toggg Exp $
+// $Header: /cvsroot/tikiwiki/tiki/lib/imagegals/imagegallib.php,v 1.45.2.41 2007/05/02 14:43:04 sylvieg Exp $
 
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
@@ -486,7 +486,7 @@ class ImageGalsLib extends TikiLib {
 					}
 
 					$imageId = $this->insert_image($galleryId, $file,
-						'', $file, $this->filetype, $this->image, $this->filesize, $this->xsize, $this->ysize, $user, '', '');
+						'', $file, $this->filetype, $this->image, $this->filesize, $this->xsize, $this->ysize, $user, '', '', NULL, NULL,$gal_info);
 
 					$numimages++;
 				}
@@ -807,7 +807,7 @@ class ImageGalsLib extends TikiLib {
 		return true;
 	}
 
-	function insert_image($galleryId, $name, $description, $filename, $filetype, &$data, $size, $xsize, $ysize, $user, $t_data, $t_type ,$lat=NULL, $lon=NULL) {
+	function insert_image($galleryId, $name, $description, $filename, $filetype, &$data, $size, $xsize, $ysize, $user, $t_data, $t_type ,$lat=NULL, $lon=NULL, $gal_info=NULL) {
 		global $gal_use_db;
 
 		global $gal_use_dir;
@@ -880,9 +880,32 @@ class ImageGalsLib extends TikiLib {
 		    $this->score_event($user, 'igallery_new_img');
 		}
 
+		$this->notify($imageId, $galleryId, $name, $filename, $description, isset($gal_info['name'])?$gal_info['name']: '', $user);
+
 		return $imageId;
 	}
 
+	function notify($imageId, $galleryId, $name, $filename, $description, $galleryName, $user) {
+		global $feature_user_watches;
+		if ($feature_user_watches == 'y') {
+			include_once('lib/notifications/notificationemaillib.php');
+			global $smarty, $tikilib;
+			$nots = $this->get_event_watches('image_gallery_changed', $galleryId);
+			$smarty->assign_by_ref('galleryId', $galleryId);
+			$smarty->assign_by_ref('galleryName', $galleryName);
+			$smarty->assign_by_ref('mail_date', date('U'));
+			$smarty->assign_by_ref('author', $user);
+			$foo = parse_url($_SERVER["REQUEST_URI"]);
+			$machine = $tikilib->httpPrefix(). dirname( $foo["path"] );
+			$smarty->assign_by_ref('mail_machine', $machine);
+			$smarty->assign_by_ref('fname', $name);
+			$smarty->assign_by_ref('filename', $filename);
+			$smarty->assign_by_ref('description', $description);
+			$smarty->assign_by_ref('imageId', $imageId);
+			sendEmailNotification($nots, 'watch', 'user_watch_image_gallery_changed_subject.tpl', NULL, 'user_watch_image_gallery_upload.tpl');
+		}
+	}
+
 	function rotate_image($id, $angle) {
 		//get image
 		global $gal_use_dir;
@@ -1948,11 +1971,11 @@ class ImageGalsLib extends TikiLib {
 							$t_type = $t_pinfo["extension"];
 							$t_type = 'image/' . $t_type;
 
-							$imageId = $this->insert_image(0, '', '', $name, $type, $data, $size, $size_x, $size_y, 'admin', $t_data, $t_type);
+							$imageId = $this->insert_image(0, '', '', $name, $type, $data, $size, $size_x, $size_y, 'admin', $t_data, $t_type, NULL, NULL, $gal_info);
 						//print("Imagen generada en $imageId<br />");
 						} else {
 							//print("No GD detected generating image without thumbnail<br />");
-							$imageId = $this->insert_image(0, '', '', $name, $type, $data, $size, 100, 100, 'admin', '', '');
+							$imageId = $this->insert_image(0, '', '', $name, $type, $data, $size, 100, 100, 'admin', '', '', NULL, NULL, $gal_info);
 						//print("Imagen en $imageId<br />");
 						}
 
@@ -1968,7 +1991,7 @@ class ImageGalsLib extends TikiLib {
 		} // foreach
 		return $page_data;
 	}
-	function get_one_image_from_disk($userfile, $galleryId=0, $name='', $description='') {
+	function get_one_image_from_disk($userfile, $galleryId=0, $name='', $description='', $gal_info='') {
 		global $tmpDir, $user;
 		$ret = array();
 		if (is_uploaded_file($_FILES[$userfile]['tmp_name'])) {
@@ -2009,7 +2032,7 @@ class ImageGalsLib extends TikiLib {
 			}
 			if ($name == '')
 				$name = $file_name;
-			if (($imageId = $this->insert_image($galleryId, $name, $description, $file_name, $type, $ret['data'], $size, 0, 0, $user, '', ''))===false) {
+			if (($imageId = $this->insert_image($galleryId, $name, $description, $file_name, $type, $ret['data'], $size, 0, 0, $user, '', '', NULL, NULL, $gal_info))===false) {
 				$ret['msg'] = tra('Upload was not successful');
 			} else {
 				$ret['imageId'] = $imageId;
