@@ -137,24 +137,24 @@ class SearchLib extends TikiLib {
 		    $sqlJoin .= " JOIN `users_objectpermissions` u ON u.`objectId` = md5(" . $this->db->concat("'$objType'", "lower($objKeyPerm)") . ") AND u.`objectType`= ? ";
 		    $bindJoin[] = $objType;
 		      
-		    if ($globalPerm == 'y') {
 			$sqlJoin = ' LEFT ' . $sqlJoin;
 			$sqlFields .= ", count(u.`objectId`) as perms, max(u.`permName`=? and u.`groupName` IN ($groupStr)) as allow ";
 			$bindFields[] = $permNameObj;
 			$bindFields = array_merge($bindFields, $groupList);
 
 			$sqlGroup = " GROUP BY $objKeyGroup ";
-			$sqlHaving = " HAVING perms=? or allow=? ";
+			$sqlHaving = " HAVING perms=?";
+			if ($globalPerm == 'y') {
+				$sqlHaving .= " or ";
+			} else {
+				$sqlHaving .= " and ";
+			}
+			$sqlHaving .= "allow=? ";
 
 			$bindHaving = array(0,1);
-		    } else {
-			$sqlJoin = ' INNER ' . $sqlJoin;
-			$sqlJoin .= " AND u.`permName`=? ";
-			$bindJoin[] = $permNameObj;
-		    }
 	 	}
 
-		$chkCatPerm = $feature_search_show_forbidden_cat != 'y' && $tiki_p_admin != 'y' && !empty($objType) && !empty($objKeyCat) && !empty($objKeyGroup) && $feature_categories == 'y' && $globalPerm == 'y';
+		$chkCatPerm = $feature_search_show_forbidden_cat != 'y' && $tiki_p_admin != 'y' && !empty($objType) && !empty($objKeyCat) && !empty($objKeyGroup) && $feature_categories == 'y';
 
 		if ($chkCatPerm) {
 
@@ -176,7 +176,13 @@ class SearchLib extends TikiLib {
 		    $sqlGroup = " GROUP BY $objKeyGroup ";
 
 		    if ($chkObjPerm) {
-			$sqlHaving = " HAVING (perms=? AND (NOT categorized OR NOT forbidden)) or allow=? ";
+			$sqlHaving = " HAVING (perms=? AND (NOT categorized OR NOT forbidden))";
+			if ($globalPerm == 'y') {
+				$sqlHaving .= " or ";
+			} else {
+				$sqlHaving .= " and ";
+			}
+			$sqlHaving .= "allow=? ";
 			$bindHaving = array(0, 1);
 		    } else {
 			$sqlHaving = " HAVING NOT categorized OR NOT forbidden ";
