@@ -1,12 +1,12 @@
 <?php
-
+// $Header: /cvsroot/tikiwiki/tiki/lib/trackers/trackerlib.php,v 1.97.2.141 2007/08/13 15:13:38 nkoth Exp $
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
   exit;
 }
 
-include_once ('lib/notifications/notificationlib.php');
+global $notificationlib; include_once ('lib/notifications/notificationlib.php');
 
 class TrackerLib extends TikiLib {
 
@@ -89,6 +89,10 @@ class TrackerLib extends TikiLib {
 		return array();
 	}
 
+	function get_item_nb_comments($itemId) {
+		return $this->getOne('select count(*) from `tiki_tracker_item_comments` where `itemId`=?', array((int)$itemId));
+	}
+
 	function list_all_attachements($offset=0, $maxRecords=-1, $sort_mode='created_desc', $find='') {
 		if ($find) {
 			$findesc = '%' . $find . '%';
@@ -370,7 +374,7 @@ class TrackerLib extends TikiLib {
 	function get_all_items($trackerId,$fieldId,$status='o') {
 		global $cachelib;
 		$sort_mode = "value_asc";
-		$cache = md5('trackerfield'.$fieldId.$status);
+		$cache = 'trackerfield'.$trackerId.'-'.$fieldId.$status;
 		if (!$cachelib->isCached($cache)) {
 			$sts = preg_split('//', $status, -1, PREG_SPLIT_NO_EMPTY);
 			$mid = " and (".implode('=? or ',array_fill(0,count($sts),'tti.`status`'))."=?) ";
@@ -412,9 +416,8 @@ class TrackerLib extends TikiLib {
 	}
 	
 	/* experimental shared */
-	function list_items($trackerId, $offset, $maxRecords, $sort_mode, $listfields, $filterfield='', $filtervalue='', $status = '', $initial = '',$exactvalue='',$numsort=false) {
+	function list_items($trackerId, $offset, $maxRecords, $sort_mode, $listfields, $filterfield='', $filtervalue='', $status = '', $initial = '',$exactvalue='',$numsort=false, $initialFieldId='') {
 		global $tiki_p_view_trackers_pending,$tiki_p_view_trackers_closed,$tiki_p_admin_trackers, $feature_categories;
-		if (isset($_REQUEST['dbg'])) { $dbg = true; } else { $dbg = false; }
 		$cat_table = '';
 		$trackerId = (int) $trackerId;
 		$mid = " where tti.`trackerId`=? ";
@@ -424,6 +427,10 @@ class TrackerLib extends TikiLib {
 				return (array("cant"=>0, "data"=>''));
 		}
 		if ($initial) {
+			if (!empty($initialFieldId)) {
+				$mid .= ' and ttif.`fieldId`=? ';
+				$bindvars[] = $initialFieldId ;
+			}
 			$mid.= "and ttif.`value` like ?";
 			$bindvars[] = $initial.'%';
 		}
@@ -470,14 +477,8 @@ class TrackerLib extends TikiLib {
 		} else {
 
 			$query = "select tti.*, ttif.`value` from `tiki_tracker_items` tti, `tiki_tracker_item_fields` ttif $mid and tti.`itemId`=ttif.`itemId` group by tti.`itemId` order by ".$this->convert_sortmode($sort_mode);
-			$query_cant = "select count(distinct ttif.`itemId`) from `tiki_tracker_items` tti, `tiki_tracker_item_fields` ttif $mid and tti.`itemId`=ttif.`itemId` group by tti.`itemId`";
+			$query_cant = "select count(distinct ttif.`itemId`) from `tiki_tracker_items` tti, `tiki_tracker_item_fields` ttif $mid and tti.`itemId`=ttif.`itemId`";
 		}
-		if ($dbg) {
-			header('Content-type: text/plain');
-			var_dump($query);
-			die();
-		}
-		if (@$_REQUEST['dbug'] == '1') { header('Content-type: text/plain');var_dump($query,$bindvars);die(); }
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
 		$type = '';
@@ -508,6 +509,7 @@ class TrackerLib extends TikiLib {
 				$fil["$inid"] = $res1['value'];
 			}
 			foreach ($listfields as $fieldId=>$fopt) {
+				$fopt['fieldId'] = $fieldId;
 				if (isset($fil[$fieldId])) {
 					$fopt['value'] = $fil[$fieldId];
 				} else {
@@ -531,7 +533,10 @@ class TrackerLib extends TikiLib {
 				} elseif ($fopt["type"] == 'e') {
 				  global $categlib; include_once('lib/categories/categlib.php');
 					$mycats = $categlib->get_child_categories($fopt['options']);
-					$zcats = $categlib->get_object_categories("tracker ".$trackerId,$res["itemId"]);
+					if (empty($zcatItemId) || $zcatItemId != $res['itemId']) {
+						$zcatItemId = $res['itemId'];
+						$zcats = $categlib->get_object_categories("tracker ".$trackerId,$res["itemId"]);
+					}
 					$cats = array();
 					foreach ($mycats as $m) {
 						if (in_array($m['categId'],$zcats)) {
@@ -542,8 +547,7 @@ class TrackerLib extends TikiLib {
 				} elseif ($fopt["type"] == 'l') {
 					$optsl = split(',',$fopt['options']);
 					$fopt["links"] = array();
-					$lst = $fil[$optsl[2]];
-					if ($lst) {
+					if (isset($optsl[2]) && ($lst = $fil[$optsl[2]])) {
 						$links = $this->get_items_list($optsl[0],$optsl[1],$lst);
 						foreach ($links as $link) {
 							$fopt["links"][$link] = $this->get_item_value($optsl[0],$link,$optsl[3]);
@@ -570,6 +574,14 @@ class TrackerLib extends TikiLib {
 								$fopt['options_array'][3] = $t * $imagegallib->ysize;
 							}
 						}
+					} else if ($fopt['type'] == 'd' || $fopt['type'] == 'D') {
+						global $feature_multilingual;
+						if ($feature_multilingual == 'y') {
+							foreach ($fopt['options_array'] as $key=>$l) {
+									$fopt['options_array'][$key] = tra($l);
+							}
+						}
+						$fopt = $this->set_default_dropdown_option($fopt);						
 					}
 				}
 				if (empty($asort_mode) || ($fieldId == $asort_mode)) {
@@ -579,7 +591,6 @@ class TrackerLib extends TikiLib {
 				$fields[] = $fopt;
 			}
 			$res["field_values"] = $fields;
-			$res["comments"] = $this->getOne("select count(*) from `tiki_tracker_item_comments` where `itemId`=?",array((int) $itid));
 			if ($kx == "") // ex: if the sort field is non visible, $kx is null
 				$ret[] = $res;
 			else
@@ -619,7 +630,7 @@ class TrackerLib extends TikiLib {
 			}
 			$mid .= " and ttif$suffix.`fieldId`=? ";
 			$bindvars[] = $filterfield;
-		} elseif ($filtervalue) {
+		} elseif ($filterfield && $filtervalue) {
 			$filter = $this->get_tracker_field($filterfield);
 			$mid.= " and ttif$suffix.`value` like ? ";
 			if (substr($filtervalue,0,1) == '*') {
@@ -672,19 +683,26 @@ class TrackerLib extends TikiLib {
 			$del_categs = array_diff($old_categs, $ins_categs);
 			$remain_categs = array_diff($old_categs, $new_categs, $del_categs);
 		}
-
-		$the_data = tra('Status:').' ';
-		$statusTypes = $this->status_types();
-		if (isset($oldStatus) && $oldStatus != $status) {
-			$the_data .= $statusTypes[$oldStatus]['label'] . ' -> ';
+		if (!empty($oldStatus) || !empty($status)) {
+			$the_data = tra('Status:').' ';
+			$statusTypes = $this->status_types();
+			if (isset($oldStatus) && $oldStatus != $status) {
+				$the_data .= $statusTypes[$oldStatus]['label'] . ' -> ';
+			}
+			if (!empty($status)) {
+				$the_data .= $statusTypes[$status]['label'] . "\n\n";
+			}
+		} else {
+			$the_data = '';
 		}
-		$the_data .= $statusTypes[$status]['label'] . "\n\n";
 
 		foreach($ins_fields["data"] as $i=>$array) {
-			if (!isset($ins_fields["data"][$i]["type"]) or $ins_fields["data"][$i]["type"] == 's' or 
-				(($ins_fields["data"][$i]["isHidden"] == 'p' or $ins_fields["data"][$i]["isHidden"] == 'y')and $tiki_p_admin_trackers != 'y')) {
+			if (!isset($ins_fields['data'][$i]['type']) or $ins_fields['data'][$i]['type'] == 's' or 
+				(isset($ins_fields['data'][$i]['isHidden']) && ($ins_fields['data'][$i]['isHidden'] == 'p' or $ins_fields['data'][$i]['isHidden'] == 'y')and $tiki_p_admin_trackers != 'y')) {
 			    // system type, do nothing
 					// hidden field type require tracker amdin perm
+			} elseif (empty($ins_fields["data"][$i]["fieldId"])) {
+					// can have been unset for a user field
 			} else {
 
 				// -----------------------------
@@ -703,8 +721,12 @@ class TrackerLib extends TikiLib {
 						if (!empty($opts[4])) {
 							global $imagegallib;include_once('lib/imagegals/imagegallib.php');
 							$imagegallib->image = $ins_fields["data"][$i]['value'];
-							$imagegallib->rescaleImage($opts[4], $opts[4]);
-							$ins_fields["data"][$i]['value'] = $imagegallib->image;
+							$imagegallib->readimagefromstring();
+							$imagegallib->getimageinfo();
+							if ($imagegallib->xsize > $opts[4] || $imagegallib->xsize > $opts[4]) {
+								$imagegallib->rescaleImage($opts[4], $opts[4]);
+								$ins_fields["data"][$i]['value'] = $imagegallib->image;
+							}
 						}
 						if ($ins_fields["data"][$i]['file_size'] <= $this->imgMaxSize) {
 
@@ -716,6 +738,7 @@ class TrackerLib extends TikiLib {
 							fwrite($fw, $ins_fields["data"][$i]['value']);
 							fflush($fw);
 							fclose($fw);
+							chmod($file_name, 0644); // seems necessary on some system (see move_uploaded_file doc on php.net
 
 							$ins_fields['data'][$i]['value'] = $file_name;
 
@@ -774,8 +797,8 @@ class TrackerLib extends TikiLib {
 					$the_data .= "\n";
 
 					if ($itemId) {
-						$query = "select `itemId` from `tiki_tracker_item_fields` where `itemId`=?";
-						if ($this->getOne($query,(int) $itemId)) {
+						$query = "select `itemId` from `tiki_tracker_item_fields` where `itemId`=? and `fieldId`=?";
+						if ($this->getOne($query,array((int) $itemId, (int) $fieldId))) {
 							$query = "update `tiki_tracker_item_fields` set `value`=? where `itemId`=? and `fieldId`=?";
 							$this->query($query,array('',(int) $itemId,(int) $fieldId));
 						} else {
@@ -836,13 +859,13 @@ class TrackerLib extends TikiLib {
 						$query = "insert into `tiki_tracker_item_fields`(`itemId`,`fieldId`,`value`) values(?,?,?)";
 						$this->query($query,array((int) $new_itemId,(int) $fieldId,(string)$value));
 					}
-					$cachelib->invalidate(md5('trackerfield'.$fieldId.'o'));
-					$cachelib->invalidate(md5('trackerfield'.$fieldId.'c'));
-					$cachelib->invalidate(md5('trackerfield'.$fieldId.'p'));
-					$cachelib->invalidate(md5('trackerfield'.$fieldId.'op'));
-					$cachelib->invalidate(md5('trackerfield'.$fieldId.'oc'));
-					$cachelib->invalidate(md5('trackerfield'.$fieldId.'pc'));
-					$cachelib->invalidate(md5('trackerfield'.$fieldId.'opc'));
+					$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'o');
+					$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'c');
+					$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'p');
+					$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'op');
+					$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'oc');
+					$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'pc');
+					$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'opc');
 				}
 			}
 		}
@@ -851,7 +874,7 @@ class TrackerLib extends TikiLib {
 		if(!$bulk_import) {
 			$options = $this->get_tracker_options( $trackerId );
 
-			include_once('lib/notifications/notificationlib.php');
+			global $notificationlib; include_once('lib/notifications/notificationlib.php');
 
 			$emails = $notificationlib->get_mail_events('tracker_modified', $trackerId);
 			$emails2 = $notificationlib->get_mail_events('tracker_item_modified', $itemId);
@@ -913,7 +936,7 @@ class TrackerLib extends TikiLib {
 
 					include_once ('lib/webmail/tikimaillib.php');
 					$mail = new TikiMail();
-					$mail->setSubject(tra('Tracker was modified at '). $_SERVER["SERVER_NAME"]);
+					$mail->setSubject($smarty->fetch('mail/tracker_changed_notification_subject.tpl'));
 					$mail->setText($mail_data);
 					$mail->setHeader("From", $sender_email);
 					$mail->send($emails);
@@ -922,8 +945,13 @@ class TrackerLib extends TikiLib {
 
 			    		global $userlib;
 
-			    		$user_email = $userlib->get_user_email($user);
-			    		$my_sender = $user_email;
+						if (!empty($user)) {
+							$my_sender = $userlib->get_user_email($user);
+						} else { // look if a email field exists
+							$fieldId = $this->get_field_id_from_type($trackerId, 'm');
+							if (!empty($fieldId))
+								$my_sender = $this->get_item_value($trackerId, (!empty($itemId)? $itemId:$new_itemId), $fieldId);
+						}
 
 			    		// Default subject
 			    		$subject='['.$trackerName.'] '.tra('Tracker was modified at '). $_SERVER["SERVER_NAME"];
@@ -931,11 +959,10 @@ class TrackerLib extends TikiLib {
 			    		// Try to find a Subject in $the_data
 			    		$subject_test = preg_match( '/^Subject:\n   .*$/m', $the_data, $matches );
 
-			    		if( $subject_test == 1 )
-			    		{
-						$subject = preg_replace( '/^Subject:\n   /m', '', $matches[0] );
-						// Remove the subject from $the_data
-						$the_data = preg_replace( '/^Subject:\n   .*$/m', '', $the_data );
+			    		if( $subject_test == 1 ) {
+							$subject = preg_replace( '/^Subject:\n   /m', '', $matches[0] );
+							// Remove the subject from $the_data
+							$the_data = preg_replace( '/^Subject:\n   .*$/m', '', $the_data );
 			    		}
 
 			    		$the_data = preg_replace( '/^.+:\n   /m', '', $the_data );
@@ -946,9 +973,8 @@ class TrackerLib extends TikiLib {
 			    		$mail->setSubject($subject);
 			    		$mail->setText($the_data);
 
-			    		if( ! empty( $my_sender ) )
-			    		{
-						$mail->setHeader("From", $my_sender);
+			    		if( ! empty( $my_sender ) ) {
+							$mail->setHeader("From", $my_sender);
 			    		}
 
 			    		$mail->send( $emails );
@@ -1094,6 +1120,8 @@ class TrackerLib extends TikiLib {
 				if (isset($f['type']) &&  $f['type'] == 'e') {
 					if (!in_array($f['fieldId'], $categorized_fields))
 						$mandatory_fields[] = $f;
+				} elseif (isset($f['type']) &&  ($f['type'] == 'u' || $f['type'] == 'g') && $f['options_array'][0] == 1) {
+					;
 				} elseif (!isset($f['value']) or strlen($f['value']) == 0) {
 					$mandatory_fields[] = $f;
 				}
@@ -1115,7 +1143,7 @@ class TrackerLib extends TikiLib {
 					if(!isset($registrationlib)) {
 						require_once('lib/registration/registrationlib.php');
 					}
-					$res = $registrationlib->SnowCheckMail($f['value'], $sender_email, false);
+					$res = $registrationlib->SnowCheckMail($f['value'], $sender_email, 'mini');
 					if($res[0] == false) {
 						$res[1];
 						$erroneous_values[] = $f;
@@ -1173,25 +1201,21 @@ class TrackerLib extends TikiLib {
 		require_once('lib/cache/cachelib.php');
 		$cachelib->invalidate('trackerItemLabel'.$itemId);
 		foreach($fieldList['data'] as $f) {
-			$cachelib->invalidate(md5('trackerfield'.$f['fieldId'].$status));
-			$cachelib->invalidate(md5('trackerfield'.$f['fieldId'].'opc'));
-			if ($status == 'o') {
-				$cachelib->invalidate(md5('trackerfield'.$f['fieldId'].'op'));
-				$cachelib->invalidate(md5('trackerfield'.$f['fieldId'].'oc'));
-			} elseif ($status == 'c') {
-				$cachelib->invalidate(md5('trackerfield'.$f['fieldId'].'oc'));
-				$cachelib->invalidate(md5('trackerfield'.$f['fieldId'].'pc'));
-			} elseif ($status == 'p') {
-				$cachelib->invalidate(md5('trackerfield'.$f['fieldId'].'op'));
-				$cachelib->invalidate(md5('trackerfield'.$f['fieldId'].'pc'));
-			}
+			$cachelib->invalidate('trackerfield'.$trackerId.'-'.$f['fieldId'].'o');
+			$cachelib->invalidate('trackerfield'.$trackerId.'-'.$f['fieldId'].'p');
+			$cachelib->invalidate('trackerfield'.$trackerId.'-'.$f['fieldId'].'c');
+			$cachelib->invalidate('trackerfield'.$trackerId.'-'.$f['fieldId'].'op');
+			$cachelib->invalidate('trackerfield'.$trackerId.'-'.$f['fieldId'].'oc');
+			$cachelib->invalidate('trackerfield'.$trackerId.'-'.$f['fieldId'].'pc');
+			$cachelib->invalidate('trackerfield'.$trackerId.'-'.$f['fieldId'].'opc');			
 		}
 
 		return true;
 	}
 
 	// Lists all the fields for an existing tracker
-	function list_tracker_fields($trackerId, $offset, $maxRecords, $sort_mode, $find) {
+	function list_tracker_fields($trackerId, $offset=0, $maxRecords=-1, $sort_mode='position_asc', $find='', $tra_name=true,$filter='') {
+		global $feature_multilingual, $language;
 		if ($find) {
 			$findesc = '%' . $find . '%';
 			$mid = " where `trackerId`=? and (`name` like ?)";
@@ -1201,6 +1225,17 @@ class TrackerLib extends TikiLib {
 			$bindvars=array((int) $trackerId);
 		}
 
+		if (!empty($filter)) {
+			foreach ($filter as $type=>$val) {
+				if ($type == 'fields') {
+					if (count($val) > 0) {
+						$mid .= ' and `fieldId` in ('.implode(",",array_fill(0,count($val),'?')).')';
+						$bindvars = array_merge($bindvars, $val);
+					}
+				}
+			}
+		}
+
 		$query = "select * from `tiki_tracker_fields` $mid order by ".$this->convert_sortmode($sort_mode);
 		$query_cant = "select count(*) from `tiki_tracker_fields` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
@@ -1208,7 +1243,17 @@ class TrackerLib extends TikiLib {
 		$ret = array();
 
 		while ($res = $result->fetchRow()) {
-			$res["options_array"] = split(',', $res["options"]);
+			$res['options_array'] = split(',', $res['options']);
+			if ($tra_name && $feature_multilingual == 'y' && $language != 'en')
+				$res['name'] = tra($res['name']);
+			if ($res['type'] == 'd' || $res['type'] == 'D') { // drop down
+				if ($feature_multilingual == 'y') {
+					foreach ($res['options_array'] as $key=>$l) {
+						$res['options_array'][$key] = tra($l);
+					}
+				}
+				$res = $this->set_default_dropdown_option($res);						
+			}
 			$ret[] = $res;
 		}
 		$retval = array();
@@ -1252,7 +1297,7 @@ class TrackerLib extends TikiLib {
 			if (!$ratingId) $ratingId = 0;
 			if (!isset($ratingoptions)) $ratingoptions = '';
 			if (!isset($showratings)) $showratings = 'n';
-			$this->replace_tracker_field($trackerId,$ratingId,'Rating','s','-','-',$showratings,'y','-','-',0,$ratingoptions);
+			$this->replace_tracker_field($trackerId,$ratingId,'Rating','s','-','-',$showratings,'y','n','-',0,$ratingoptions);
 		} else {
 			$this->query('delete from `tiki_tracker_fields` where `fieldId`=?',array((int)$ratingId));
 		}
@@ -1396,14 +1441,13 @@ class TrackerLib extends TikiLib {
 		$result = $this->query($query,$bindvars);
 		$query = "delete from `tiki_tracker_item_fields` where `fieldId`=?";
 		$result = $this->query($query,$bindvars);
-		$cachelib->invalidate(md5('trackerfield'.$fieldId.'o'));
-		$cachelib->invalidate(md5('trackerfield'.$fieldId.'p'));
-		$cachelib->invalidate(md5('trackerfield'.$fieldId.'c'));
-		$cachelib->invalidate(md5('trackerfield'.$fieldId.'op'));
-		$cachelib->invalidate(md5('trackerfield'.$fieldId.'oc'));
-		$cachelib->invalidate(md5('trackerfield'.$fieldId.'pc'));
-		$cachelib->invalidate(md5('trackerfield'.$fieldId.'opc'));
-		$cachelib->invalidate(md5('trackerfield'.$fieldId.'poc'));
+		$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'o');
+		$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'p');
+		$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'c');
+		$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'op');
+		$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'oc');
+		$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'pc');
+		$cachelib->invalidate('trackerfield'.$trackerId.'-'.$fieldId.'opc');		
 
 		$this->clear_tracker_cache($trackerId);
 
@@ -1433,8 +1477,14 @@ class TrackerLib extends TikiLib {
 		return $this->getOne("select `fieldId` from `tiki_tracker_fields` where `trackerId`=? and `name`=?",array((int)$trackerId,$name));
 	}
 
-	function get_field_id_from_type($trackerId, $type, $option) {
-		return $this->getOne("select `fieldId` from `tiki_tracker_fields` where `trackerId`=? and `type`=? and `options`=?",array((int)$trackerId,$type,$option));
+	function get_field_id_from_type($trackerId, $type, $option=NULL) {
+		$mid = ' `trackerId`=? and `type`=? ';
+		$bindvars = array((int)$trackerId, $type);
+		if (!empty($option)) {
+			$mid .= ' and `options`=? ';
+			$bindvars[] = $option;
+		} 
+		return $this->getOne("select `fieldId` from `tiki_tracker_fields` where $mid",$bindvars);
 	}
 
 /*
@@ -1499,7 +1549,11 @@ class TrackerLib extends TikiLib {
 		$type['d'] = array(
 			'label'=>tra('drop down'),
 			'opt'=>true,
-			'help'=>tra('Dropdown options: list of items separated with commas.') );
+			'help'=>tra('Dropdown options: list of items separated with commas.').tra('Default value is specified by having the value indicated twice consecutively') );
+		$type['D'] = array(
+			'label'=>tra('drop down with other textfield'),
+			'opt'=>true,
+			'help'=>tra('Dropdown options: list of items separated with commas.').tra('Default value is specified by having the value indicated twice consecutively') );
 		$type['u'] = array(
 			'label'=>tra('user selector'),
 			'opt'=>true,
@@ -1566,12 +1620,13 @@ class TrackerLib extends TikiLib {
 	}
 	function categorized_item($trackerId, $itemId, $mainfield, $ins_categs) {
 		global $categlib; include_once('lib/categories/categlib.php');
-		if (count($ins_categs) <= 0)
-			return;
 		$cat_type = "tracker $trackerId";
 		$cat_objid = $itemId;
 		$cat_desc = '';
-		$cat_name = $mainfield;
+		if (empty($mainfield))
+			$cat_name = $itemId;
+		else
+			$cat_name = $mainfield;
 		$cat_href = "tiki-view_tracker_item.php?trackerId=$trackerId&amp;itemId=$itemId";
 		$categlib->uncategorize_object($cat_type, $cat_objid);
 		foreach ($ins_categs as $cats) {
@@ -1602,6 +1657,51 @@ class TrackerLib extends TikiLib {
 		}
 		return $ret;
 	}
+	/* find the best fieldwhere you can do a filter on the initial
+	 * 1) if sort_mode and sort_mode is a text and the field is visible
+	 * 2) the first main taht is text
+	 */
+	function get_initial_field($list_fields, $sort_mode) {
+		if (preg_match('/^f_([^_]*)_?.*/', $sort_mode, $matches)) {
+			if (isset($list_fields[$matches[1]])) {
+				$type = $list_fields[$matches[1]]['type'];
+				if ($type == 't' || $type == 'a' || $type == 'm')
+					return $matches[1];
+			}
+		}
+		foreach($list_fields as $fieldId=>$field) {
+			if ($field['isMain'] == 'y' && ($field['type'] == 't' || $field['type'] == 'a' || $field['type'] == 'm'))
+				return $fieldId;
+		}
+		return '';
+	}
+	function get_flags() {
+		$flags = array();
+		$h = opendir("img/flags/");
+		while ($file = readdir($h)) {
+			if (strstr($file, ".gif")) {
+				$parts = explode('.', $file);
+				$flags[] = $parts[0];
+			}
+		}
+		closedir ($h);
+		sort($flags, SORT_STRING);
+		return $flags;	
+	}
+	// look for default value: a default value is 2 consecutive same value
+	function set_default_dropdown_option($field) {
+		for ($io = 0; $io < sizeof($field['options_array']); ++$io) {
+			if ($io > 0 && $field['options_array'][$io] == $field['options_array'][$io - 1]) {
+				$field['defaultvalue'] = $field['options_array'][$io];
+				for (; $io < sizeof($field['options_array']) - 1; ++$io) {
+					$field['options_array'][$io] = $field['options_array'][$io + 1];
+				}
+				unset($field['options_array'][$io]);
+				break;
+			}
+		}
+		return $field;
+	}
 
 }
 
