@@ -74,24 +74,17 @@ class UsersLib extends TikiLib {
 
     function object_has_permission($user, $objectId, $objectType, $permName) {
 	$groups = $this->get_user_groups($user);
-
 	$objectId = md5($objectType . strtolower($objectId));
-
-	foreach ($groups as $groupName) {
-	    $query = "select count(*)
-		from `users_objectpermissions`
-		where `groupName` = ? and `objectId` = ?
-		and `objectType` = ? and `permName` = ?";
-
-	    $bindvars = array($groupName, $objectId, $objectType,
-		    $permName);
-	    $result = $this->getOne($query, $bindvars);
-
-	    if ($result>0)
+	$mid = implode(',',array_fill(0,count($groups),'?'));
+	$query = "select count(*) from `users_objectpermissions` where `groupName` in ($mid) and `objectId` = ? and `objectType` = ? and `permName` = ?";
+    $bindvars = array_merge($groups, array($objectId, $objectType, $permName));
+    $result = $this->getOne($query, $bindvars);
+    if ($result > 0) {
 		return true;
+	} else {
+		return false;
 	}
 
-	return false;
     }
 
     function remove_object_permission($groupName, $objectId, $objectType, $permName) {
@@ -209,10 +202,8 @@ class UsersLib extends TikiLib {
     }
 
     function user_logout($user) {
-	$t = date("U");
-	// No need to change lastLogin since it is handled at the validateUser method
-	//$query = "update `users_users` set `lastLogin`=$t where `login`='$user'";
-	//$result = $this->query($query);
+			$query = 'delete from `tiki_user_preferences` where `prefName`=? and `user`=?';
+			$user = $this->query($query, array('cookie',(string)$user));
     }
     
     function user_logout_cas() {
@@ -274,13 +265,16 @@ class UsersLib extends TikiLib {
     }
 
     function validate_user(&$user, $pass, $challenge, $response) {
-	global $tikilib, $sender_email, $feature_intertiki, $feature_intertiki_mymaster;
+	global $tikilib, $sender_email, $feature_intertiki, $feature_intertiki_mymaster, $min_pass_length;
 
 	if ($user != 'admin' && $feature_intertiki == 'y' && !empty($feature_intertiki_mymaster)) {
 	    // slave intertiki sites should never check passwords locally, just for admin
 	    return false;
 	}
 
+	if (strlen($pass) < $min_pass_length) {
+		return false;
+	}
 	// these will help us keep tabs of what is going on
 	$userTiki = false;
 	$userTikiPresent = false;
@@ -895,6 +889,7 @@ function get_users($offset = 0, $maxRecords = -1, $sort_mode = 'login_asc', $fin
 	    $aux["groups"] = $groups;
 	    $aux["currentLogin"] = $res["currentLogin"];
 	    $aux["age"] = $now - $res["registrationDate"];
+		$aux['provpass'] = $res['provpass'];
 	    $ret[] = $aux;
 	}
 
@@ -955,7 +950,7 @@ function get_included_groups($group) {
 	    $bindvars = array($initial . "%");
 	}
 	if ($inGroups) {
-		$mid = $mid? ' and ': ' where ';
+		$mid .= $mid? ' and ': ' where ';
 		$mid .= '`groupName` in (';
 		$cpt = 0;
 		foreach ($inGroups as $grp=>$value) {
@@ -1166,6 +1161,7 @@ function get_included_groups($group) {
 
     function remove_group($group) {
 	global $cachelib;
+	if ( $group == 'Anonymous' || $group == 'Registered' || $group == 'Admins' ) return false;
 	$query = "delete from `users_groups` where `groupName` = ?";
 	$result = $this->query($query, array($group));
 	$query = "delete from `tiki_group_inclusion` where `groupName` = ? or `includeGroup` = ?";
@@ -1692,35 +1688,39 @@ function get_included_groups($group) {
 	    $provpass = '';
 	}
 
-	$query = "update `users_users` set `password`=? ,`hash`=? ,`provpass`=? where `login`=?";
+	$query = "update `users_users` set `password`=? ,`hash`=? ,`provpass`=?,valid=? where `login`=?";
 	$result = $this->query($query, array(
 		    $provpass,
 		    $hash,
 		    '',
+			NULL,
 		    $user
 		    ));
 			$cachelib->invalidate('userslist');
     }
 
-    function add_user($user, $pass, $email, $provpass = '') {
-	global $pass_due, $tikilib, $cachelib;
+    function add_user($user, $pass, $email, $provpass = '', $valid=NULL) {
+	global $pass_due, $tikilib, $cachelib, $patterns;
 	global $feature_clear_passwords;
 	// Generate a unique hash; this is also done below in set_user_fields()
 	//$hash = md5($user . $pass . $email);
 	$hash = md5($user . $pass);
 
+	if ($valid == 'n') {
+		$valid = $pass;
+	}
 	if ($feature_clear_passwords == 'n')
 	    $pass = '';
 
-	if ($this->user_exists($user) || empty($user))
+	if ($this->user_exists($user) || empty($user) || !preg_match($patterns['login'],$user))
 	    return false;
 
 	$now = date("U");
 	$new_pass_due = $now + (60 * 60 * 24 * $pass_due);
 	$query = "insert into
 	    `users_users`(`login`, `password`, `email`, `provpass`,
-		    `registrationDate`, `hash`, `pass_due`, `created`)
-	    values(?,?,?,?,?,?,?,?)";
+		    `registrationDate`, `hash`, `pass_due`, `created`, `valid`)
+	    values(?,?,?,?,?,?,?,?,?)";
 	$result = $this->query($query, array(
 		    $user,
 		    $pass,
@@ -1729,7 +1729,8 @@ function get_included_groups($group) {
 		    (int) $now,
 		    $hash,
 		    (int) $new_pass_due,
-		    (int) $now
+		    (int) $now,
+			$valid
 		    ));
 
 	$this->assign_user_to_group($user, 'Registered');
@@ -1749,7 +1750,7 @@ function get_included_groups($group) {
 
     function change_user_email($user, $email, $pass) {
     // Need to change the email-address for notifications, too
-    include_once('lib/notifications/notificationlib.php');
+	global $notificationlib; include_once('lib/notifications/notificationlib.php');
     $oldMail = $this->get_user_email($user);
     $notificationlib->update_mail_address($oldMail, $email);
     
@@ -1781,10 +1782,14 @@ function get_included_groups($group) {
     }
 
     function get_user_password($user) {
-	$query = "select `password`  from `users_users` where " . $this->convert_binary(). " `login`=?";
+	$query = "select `password`,`provpass`  from `users_users` where " . $this->convert_binary(). " `login`=?";
 
-	$pass = $this->getOne($query, array($user));
-	return $pass;
+	$result = $this->query($query, array($user));
+	$res = $result->fetchRow();
+	if (empty($res['provpass']))
+		return $res['password'];
+	else
+		return $res['provpass'];
     }
 
     function get_user_email($user) {
@@ -1815,6 +1820,32 @@ function get_included_groups($group) {
 	return $pass;
     }
 
+  function create_user_cookie($user) {
+    global $remembertime;
+    $hash = md5($_SERVER['REMOTE_ADDR'].$_SERVER['HTTP_USER_AGENT']);
+    $hash.= ".". (date('U') + $remembertime);
+    $this->set_user_preference($user,'cookie',$hash);
+    return $hash;
+  }
+
+  function get_user_by_cookie($hash) {
+	list($check,$expire,$userCookie) = explode('.',$hash);
+    if ($check == md5($_SERVER['REMOTE_ADDR'].$_SERVER['HTTP_USER_AGENT'])) {
+      $query = 'select `user` from `tiki_user_preferences` where `prefName`=? and `value`=? and `user`=?';
+      $user = $this->getOne($query, array('cookie',"$check.$expire", $userCookie));
+      if ($user) {
+        if ($expire < date('U')) {
+          $query = 'delete from `tiki_user_preferences` where `prefName`=? and `value`=?';
+          $user = $this->query($query, array('cookie',$hash));
+          return false;
+        } else {
+          return $user;
+        }
+      }
+    }
+    return false;
+  }
+
     function get_user_by_email($email) {
     $query = "select `login` from `users_users` where `email`=?";
     $pass = $this->getOne($query, array($email));
@@ -1901,6 +1932,11 @@ function get_included_groups($group) {
 
 	function change_group($olgroup,$group,$desc,$home,$utracker=0,$gtracker=0,$ufield=0,$gfield=0) {
 		global $cachelib;  
+
+//		marclaporte: commenting below because it is possible to edit some things for these groups (ex.: group home page).
+//		There is a protection in the tpl to prevent renaming.
+//		if ( $olgroup == 'Anonymous' || $olgroup == 'Registered' ) return false;
+
 		if (!$this->group_exists($olgroup))
 			return $this->add_group($group, $desc, $home,$utracker,$gtracker);
 		$query = "update `users_groups` set `groupName`=?, `groupDesc`=?, `groupHome`=?, ";
@@ -1914,6 +1950,8 @@ function get_included_groups($group) {
 		$result = $this->query($query, array($group, $olgroup));
 		$query = "update `tiki_group_inclusion` set `groupName`=? where `groupName`=?";
 		$result = $this->query($query, array($group, $olgroup));
+		$query = "update `tiki_group_inclusion` set `includeGroup`=? where `includeGroup`=?";
+		$result = $this->query($query, array($group, $olgroup));
 		$query = "update `tiki_newsreader_marks` set `groupName`=? where `groupName`=?";
 		$result = $this->query($query, array($group, $olgroup));
 		$query = "update `tiki_newsletter_groups` set `groupName`=? where `groupName`=?";
@@ -2158,6 +2196,55 @@ function get_included_groups($group) {
 		while ($res = $result->fetchRow()) { $ret[] = $res['type']; }
 		return $ret;									
 	}
+	function send_validation_email($name, $apass, $email, $again='') {
+		global $tikilib, $validateRegistration, $validateUsers, $sender_email, $smarty;
+		$foo = parse_url($_SERVER['REQUEST_URI']);
+		$foo1 = str_replace('tiki-register', 'tiki-login_validate',$foo['path']);
+		$foo1 = str_replace('tiki-remind_password', 'tiki-login_validate',$foo1);
+		$machine = $tikilib->httpPrefix().$foo1;
+		$smarty->assign('mail_machine',$machine);
+		$smarty->assign('mail_site', $_SERVER['SERVER_NAME']);
+		$smarty->assign('mail_user', $name);
+		$smarty->assign('mail_apass', $apass);
+		$smarty->assign('mail_email', $email);
+		$smarty->assign('mail_again', $again);
+		include_once('lib/webmail/tikimaillib.php');
+		if ($validateRegistration == 'y') {
+			$mail_data = $smarty->fetch('mail/moderate_validation_mail.tpl');
+			$mail_subject = $smarty->fetch('mail/moderate_validation_mail_subject.tpl');
+			if ($sender_email == NULL or !$sender_email) {
+				include_once('lib/messu/messulib.php');
+				$messulib->post_message($contact_user, $contact_user, $contact_user, '', $mail_subject, $mail_data, 5);
+			} else {
+				$mail = new TikiMail();
+				$mail->setText($mail_data);
+				$mail->setSubject($mail_subject);
+				if (!$mail->send(array($sender_email))) {
+					$smarty->assign('msg', tra("The registration mail can't be sent. Contact the administrator"));
+					return false;
+				} elseif (empty($again)) {
+					$smarty->assign('msg', $smarty->fetch('mail/user_validation_waiting_msg.tpl'));
+				} else {
+					$smarty->assign('msg', tra('The administrator has not yet validated your account. Please wait.'));
+				}
+			}
+		} elseif ($validateUsers == 'y') {
+			$mail_data = $smarty->fetch('mail/user_validation_mail.tpl');
+			$mail = new TikiMail();
+			$mail->setText($mail_data);
+			$mail_data = $smarty->fetch('mail/user_validation_mail_subject.tpl');
+			$mail->setSubject($mail_data);
+			if (!$mail->send(array($email))) {
+				$smarty->assign('msg', tra("The registration mail can't be sent. Contact the administrator"));
+				return false;
+			} elseif (empty($again)) {
+				$smarty->assign('msg',$smarty->fetch('mail/user_validation_msg.tpl'));
+			} else {
+				$smarty->assign('msg', tra('You must validate your account first. An email has been sent to you'));
+			}
+		}
+		return true;
+	}
 
 }
 
