@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/lib/wiki-plugins/wikiplugin_flash.php,v 1.2.2.3 2006/01/26 14:28:26 thenano Exp $
+// $Header: /cvsroot/tikiwiki/tiki/lib/wiki-plugins/wikiplugin_flash.php,v 1.2.2.6 2007/06/10 19:41:50 sylvieg Exp $
 
 // Wiki plugin to display a SWF file
 // damian aka damosoft 30 March 2004
@@ -13,9 +13,25 @@ function wikiplugin_flash($data, $params) {
 	
 	extract ($params,EXTR_SKIP);
 
+	if (empty($movie)) {
+		return tra('Missing parameter movie to the plugin flash');
+	}
+	
+	if (!isset($width)) {
+	$width = "425";
+	}	
+
+	if (!isset($height)) {
+	$height = "350";
+	}	
+
+	if (!isset($quality)) {
+	$quality = "high";
+	}	
+
 	$asetup = "<OBJECT CLASSID=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" codebase=\"http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,29,0\" WIDTH=\"$width\" HEIGHT=\"$height\">";
 	$asetup .= "<PARAM NAME=\"movie\" VALUE=\"$movie\">";
-	$asetup .= "<PARAM NAME=\"quality\" VALUE=\$quality\">";
+	$asetup .= "<PARAM NAME=\"quality\" VALUE=\"$quality\">";
 	$asetup .= "<PARAM NAME=\"wmode\" VALUE=\"transparent\">";
 	$asetup .= "<embed src=\"$movie\" quality=\"$quality\" pluginspage=\"http://www.macromedia.com/go/getflashplayer\" type=\"application/x-shockwave-flash\" width=\"$width\" height=\"$height\" wmode=\"transparent\"></embed></object>";
 
