@@ -14,7 +14,7 @@ if ($user && isset($feature_tasks) && $feature_tasks == 'y' && isset($tiki_p_tas
 		global $dbTiki;
 		include "lib/tasks/tasklib.php";
 	}
-    $smarty->assign('ownurl', $tikilib->httpPrefix().$_SERVER["SCRIPT_NAME"].urlencode($_SERVER["QUERY_STRING"]));
+    $smarty->assign('ownurl', $tikilib->httpPrefix().$_SERVER["SCRIPT_NAME"].'?'.urlencode($_SERVER["QUERY_STRING"]));
 	$user_groups = $tasklib->get_groups_to_user_with_permissions($user,'tiki_p_tasks_receive');
 
 	if (isset($_REQUEST["modTasksSearch"])) {
