@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-editpage.php,v 1.89.2.58 2006/09/03 16:32:31 ohertel Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-editpage.php,v 1.89.2.64 2007/07/27 17:21:50 ricks99 Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -793,9 +793,10 @@ if ($feature_polls =='y' and $feature_wiki_ratings == 'y' && $tiki_p_wiki_admin_
 		$smarty->assign('poll_template',$_REQUEST['poll_template']);
 	}
 	$listpolls = $polllib->get_polls('o',"$page: ");
-	if ($listpolls['data']) {
+	/*	if ($listpolls['data']) {
 		$listpolls['data'] = array_map('pollnameclean',$listpolls['data']);
 	}
+*/
 	$smarty->assign('listpolls',$listpolls['data']);
 }
 
@@ -803,6 +804,8 @@ if ($feature_multilingual == 'y') {
 	$languages = array();
 	$languages = $tikilib->list_languages();
 	$smarty->assign_by_ref('languages', $languages);
+	$available_languages = unserialize($tikilib->get_preference("available_languages"));
+	$smarty->assign_by_ref('available_languages', $available_languages);
 }
 
 $cat_type = 'wiki page';
@@ -861,6 +864,15 @@ if (isset($_REQUEST['cat_categorize'])) {
     $smarty->assign('categ_checked', 'y');
   }
 }
+
+if ($wiki_feature_copyrights == 'y' && $tiki_p_edit_copyrights == 'y') {
+	include_once ('lib/copyrights/copyrightslib.php');
+	$copyrightslib = new CopyrightsLib($dbTiki);
+	$copyrights = $copyrightslib->list_copyrights($_REQUEST["page"]);
+	if ($copyrights['cant'])
+	$smarty->assign_by_ref('copyrights', $copyrights['data']);
+}
+
 include_once("textareasize.php");
 
 include_once ('lib/quicktags/quicktagslib.php');
@@ -872,8 +884,13 @@ if (!$user or $user == 'anonymous') {
 	$smarty->assign('anon_user', 'y');
 }
 
+// Get edit session timeout in minutes
+$smarty->assign('edittimeout', (ini_get('session.gc_maxlifetime') / 60 ));
+
+
 ask_ticket('edit-page');
 
+
 // disallow robots to index page:
 $smarty->assign('metatag_robots', 'NOINDEX, NOFOLLOW');
 
