@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-install.php,v 1.62.2.28 2006/11/06 20:48:21 mose Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-install.php,v 1.62.2.31 2007/03/02 13:59:00 luciash Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -175,15 +175,15 @@ function isWindows() {
 	return $windows;
 }
 
-class Smarty_TikiWiki extends Smarty {
+class Smarty_Tikiwiki extends Smarty {
 
-	function Smarty_TikiWiki() {
+	function Smarty_Tikiwiki() {
 		$this->template_dir = "templates/";
 		$this->compile_dir = "templates_c/";
 		$this->config_dir = "configs/";
 		$this->cache_dir = "cache/";
 		$this->caching = false;
-		$this->assign('app_name', 'TikiWiki');
+		$this->assign('app_name', 'Tikiwiki');
 		$this->plugins_dir = array(
 			dirname(dirname(SMARTY_DIR))."/smarty_tiki",
 			SMARTY_DIR."plugins"
@@ -223,11 +223,15 @@ function kill_script() {
 
 	if ($removed == true) {
 		header ('location: tiki-index.php');
-	} else {
-		print "<html><body>
-<p><font color='red'><b>Security Alert!</b><br />
-Tiki installer failed to rename <b>tiki-install.php</b>.  Please remove or rename the file, <b>tiki-install.php</b>, manually.  Others can potentially wipe out your Tiki database if you do not remove or rename this file.</b></font><br />
-<a href='index.php'>Proceed to your site</a> after you have removed or renamed <b>tiki-install.php</b></p>
+	} else { // TODO: display this via translantable error msg template ?
+		print "<html><head><title>Ooops !</title></head><body>
+<h1 style='color: red'>Ooops !</h1>
+<p>Tikiwiki installer failed to rename the <b>tiki-install.php</b> file.</p>
+<p style='border: solid 1px red; margin: 0 10% 0 10%; text-align: center; width: 80%'>Leaving this file on a publicly accessible site is a <strong>security risk</strong>.</p>
+<p>Please remove or rename the <b>tiki-install.php</b> from your Tiki installation folder 'manually' (e.g. using SSH or FTP).
+<strong>Somebody else could be potentially able to wipe out your Tikiwiki database if you do not remove or rename this file !</strong></p>
+<p><a href='index.php'>Proceed to your site</a> after you have removed or renamed <b>tiki-install.php</b>.</p>
+<p style='text-align: right'>Thank you</p>
 </body></html>";
 	}
 	die;
@@ -487,7 +491,7 @@ if ($virtuals and isset($_REQUEST['multi']) and in_array($_REQUEST['multi'],$vir
 }
 
 // Init smarty
-$smarty = new Smarty_TikiWiki();
+$smarty = new Smarty_Tikiwiki();
 //$smarty->load_filter('pre', 'tr');
 $smarty->load_filter('output', 'trimwhitespace');
 $smarty->assign('mid', 'tiki-install.tpl');
