@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-setup.php,v 1.240.2.143 2006/11/15 14:18:28 sylvieg Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-setup.php,v 1.240.2.161 2007/09/12 15:25:47 marclaporte Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -72,7 +72,7 @@ class TikiSetup extends TikiInit {
                 $save_path = TikiSetup::tempdir();
 
                 if (is_dir($save_path) && is_writeable($save_path)) {
-                    ini_set('session.save_path', $save_path);
+                    session_save_path($save_path);
 
                     $errors = '';
                 }
@@ -139,7 +139,7 @@ class TikiSetup extends TikiInit {
 
             print "
 <html><body>
-<h2><font color='red'>TikiWiki is not properly set up:</font></h1>
+<h2><font color='red'>Tikiwiki is not properly set up:</font></h1>
 <pre>
 $errors
 ";
@@ -238,6 +238,7 @@ $tikifeedback = array();
 $feature_referer_highlight = 'n';
 
 include_once ("tiki-setup_base.php");
+
 TikiSetup::check($tikidomain);
 //print("tiki-setup: before rest of tiki-setup:".$tiki_timer->elapsed()."<br />");
 
@@ -382,7 +383,10 @@ $feature_wiki_undo = 'n';
 $feature_wiki_multiprint = 'n';
 $feature_wiki_pdf = 'n';
 $feature_wiki_export = 'y';
+$feature_wiki_import_page = 'y';
+$feature_wiki_history_full = 'n';
 $smarty->assign('feature_wiki_export', $feature_wiki_export);
+$smarty->assign('feature_wiki_import_page', $feature_wiki_import_page);
 $feature_forum_rankings = 'y';
 $feature_forum_parse = 'n';
 $feature_forum_quickjump = 'n';
@@ -454,7 +458,7 @@ $smarty->assign('feature_wiki_allowhtml ', $feature_wiki_allowhtml );
 $feature_help = 'y';
 $smarty->assign('feature_help', $feature_help);
 
-$helpurl = "http://doc.tikiwiki.org/tiki-index.php?best_lang&amp;page=";
+$helpurl = "http://doc.tikiwiki.org/tiki-index.php?page=";
 $smarty->assign('helpurl', $helpurl);
 
 $feature_usability = 'n';
@@ -754,7 +758,7 @@ $feature_charts = 'n';
 $smarty->assign('feature_charts', $feature_charts);
 $feature_user_watches = 'n';
 $smarty->assign('feature_user_watches', $feature_user_watches);
-$feature_user_watches_translations = 'y';
+$feature_user_watches_translations = 'n';
 $smarty->assign('feature_user_watches_translations', $feature_user_watches_translations);
 $feature_mobile = 'n';
 $smarty->assign('feature_mobile', $feature_mobile);
@@ -805,7 +809,7 @@ $rnd_num_reg = 'n';
 $smarty->assign('rnd_num_reg', $rnd_num_reg);
 $allowmsg_is_optional = 'y';
 $smarty->assign('allowmsg_is_optional', $allowmsg_is_optional);
-$allowmsg_by_default = 'n';
+$allowmsg_by_default = 'y';
 $smarty->assign('allowmsg_by_default', $allowmsg_by_default);
 
 $smarty->assign('feature_page_title', $feature_page_title);
@@ -1220,7 +1224,7 @@ $smarty->assign('feature_mods_provider', $feature_mods_provider);
 $mods_dir = 'mods';
 $smarty->assign('mods_dir', $mods_dir);
 
-$mods_server = 'http://tikiwiki.org/mods';
+$mods_server = 'http://mods.tikiwiki.org/';
 $smarty->assign('mods_server', $mods_server);
 
 // hmm
@@ -1237,15 +1241,20 @@ $site_crumb_seper='>';
 $smarty->assign('site_crumb_seper', $site_crumb_seper);
 
 $feature_sitemycode='n';
-$sitemycode='<div align="center"><b>{tr}Here you can (as an admin) place a piece of custom XHTML and/or Smarty code. Be careful and properly close all the tags before you choose to publish ! (Javascript, applets and object tags are stripped out.){/tr}</b></div>'; // must be max. 250 chars now unless it'll change in tiki_prefs db table field value from VARCHAR(250) to BLOB by default
+$sitemycode='<div style="text-align: center; padding-top: 10px">
+<a href="."><img alt="" src="img/tiki/tw_logo.png" border="0" hspace="10"></a>
+<span style="font-size:3em; font-weight: bold; vertical-align:bottom">
+{$siteTitle}
+</span>
+</div>'; 
 $sitemycode_publish='n';
 $smarty->assign('feature_sitemycode', $feature_sitemycode);
 $smarty->assign('sitemycode', $sitemycode);
 $smarty->assign('sitemycode_publish', $sitemycode_publish);
 
-$feature_sitelogo='y';
+$feature_sitelogo='n';
 $sitelogo_bgcolor='';
-$sitelogo_title='TikiWiki powered site';
+$sitelogo_title='Tikiwiki powered site';
 $sitelogo_src='img/tiki/tikilogo.png';
 $sitelogo_alt='Site Logo';
 $smarty->assign('feature_sitelogo', $feature_sitelogo);
@@ -1262,7 +1271,7 @@ $sitenav='{tr}Navigation : {/tr}<a href="tiki-contact.php" accesskey="10" title=
 $smarty->assign('feature_sitenav', $feature_sitenav);
 $smarty->assign('sitenav', $sitenav);
 
-$feature_sitead='y';
+$feature_sitead='n';
 $sitead='';
 $sitead_publish='n';
 $smarty->assign('feature_sitead', $feature_sitead);
@@ -1271,9 +1280,9 @@ $smarty->assign('sitead_publish', $sitead_publish);
 
 $feature_breadcrumbs='n';
 $smarty->assign('feature_breadcrumbs', $feature_breadcrumbs);
-$feature_siteloclabel='y';
+$feature_siteloclabel='n';
 $smarty->assign('feature_siteloclabel', $feature_siteloclabel);
-$feature_sitesearch='y';
+$feature_sitesearch='n';
 $smarty->assign('feature_sitesearch', $feature_sitesearch);
 $feature_sitemenu='n';
 $smarty->assign('feature_sitemenu', $feature_sitemenu);
@@ -1562,7 +1571,7 @@ if ($feature_userPreferences == 'y') {
 			$tikilib->set_user_preference($user, 'language', $language);
 		} else {
             	$user_language = $tikilib->get_user_preference($user, 'language', $language);
-	            if ($user_language) {
+	            if ($user_language && $language != $user_language && file_exists("lang/$user_language/language.php")) {
                 		$language = $user_language;
             	}
 		}
@@ -1587,7 +1596,10 @@ if (!$user) {
 		$language = $saveLanguage;
 		$smarty->assign('language', $language);
 	}
-}
+ } elseif (!empty($saveLanguage) && $feature_userPreferences != 'y' && $change_language == 'y') {
+ 	$language = $saveLanguage;
+	$smarty->assign('language', $language);
+ }
 
 $stlstl = split("-|\.", $style);
 $style_base = $stlstl[0];
@@ -1764,7 +1776,7 @@ if ($feature_warn_on_edit == 'y') {
 }
 
 $ownurl = $tikilib->httpPrefix(). $_SERVER["REQUEST_URI"];
-$parsed = parse_url($_SERVER["REQUEST_URI"]);
+$parsed = @parse_url($_SERVER["REQUEST_URI"]);
 
 if (!isset($parsed["query"])) {
     $parsed["query"] = '';
@@ -1878,13 +1890,11 @@ if (ini_get('zlib.output_compression') == 1) {
     $smarty->assign('gzip','Enabled');
     $smarty->assign('gzip_handler','php');
 // if not, check if tiki compression is enabled
-} elseif ($feature_obzip == 'y') {
+} elseif ($feature_obzip == 'y' && (empty($output_zip) || $output_zip != 'n')) {
 	// tiki compression is enabled, then let activate the handler
-	if ($feature_obzip == 'y') {
-	    ob_start ("ob_gzhandler");
-			$smarty->assign('gzip_handler','tiki');
-    	$smarty->assign('gzip','Enabled');
-	}
+	ob_start ("ob_gzhandler");
+	$smarty->assign('gzip_handler','tiki');
+	$smarty->assign('gzip','Enabled');
 }
 
 //print("tiki-setup: before include debugger.php:".$tiki_timer->elapsed()."<br />");
@@ -1962,13 +1972,13 @@ if (is_file('.lastup') and is_readable('.lastup')) {
 }
 
 if ($feature_wiki_discuss == 'y') {
-	$wiki_discussion_string = tra ("Use this thread to discuss the page:", $tikilib->get_preference('language', 'en'));
+	$wiki_discussion_string = $smarty->fetchLang($tikilib->get_preference('language', 'en'), 'wiki-discussion.tpl');
 	$smarty->assign('wiki_discussion_string', $wiki_discussion_string);
 }
 // ------------------------------------------------------
 // setup initial breadcrumb
 $crumbs = array();
-$crumbs[] = new Breadcrumb($siteTitle,"Home",$tikiIndex);
+$crumbs[] = new Breadcrumb($siteTitle,'',$tikiIndex);
 $smarty->assign_by_ref('crumbs', $crumbs);
 
 
