@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-setup_base.php,v 1.78.2.65 2006/11/21 15:23:30 mose Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-setup_base.php,v 1.78.2.72 2007/08/27 11:40:17 mose Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -45,6 +45,7 @@ require_once("setup_smarty.php");
 require_once("lib/tikilib.php");
 require_once("lib/cache/cachelib.php");
 require_once("lib/logs/logslib.php");
+include_once('lib/init/tra.php');
 
 $tikilib = new TikiLib($dbTiki);
 require_once("lib/userslib.php");
@@ -106,9 +107,10 @@ if ( false ) { // if pre-PHP 4.1 compatibility is not required
 }
 
 // mose : simulate strong var type checking for http vars
+$patterns['login']   = "/^[-_a-zA-Z0-9@\.]*$/"; // special check for logins, not to be used in varcheck because compat with already created accounts
 $patterns['int']   = "/^[0-9]*$/"; // *Id
 $patterns['intSign']   = "/^[-+]?[0-9]*$/"; // *offset,
-$patterns['char']  = "/^[-,_a-zA-Z0-9]*$/"; // sort_mode, 
+$patterns['char']  = "/^[-,_a-zA-Z0-9]*$/"; // sort_mode 
 $patterns['string']  = "/^<\/?(b|strong|small|br *\/?|ul|li|i)>|[^<>\";#]*$/"; // find, and such extended chars
 $patterns['stringlist']  = "/^[^<>\"#]*$/"; // to, cc, bcc (for string lists like: user1;user2;user3)
 $patterns['vars']  = "/^[-_a-zA-Z0-9]*$/"; // for variable keys
@@ -158,6 +160,8 @@ $vartype['actpass'] = '+string'; // remind password page
 $vartype['user'] = '+string'; // remind password page
 $vartype['remind'] = 'string'; // remind password page
 $vartype['url'] = 'url';
+$vartype['game'] = 'string'; // from games
+$vartype['username'] = 'login'; // from games
 // galaxia
 $vartype['aid'] = '+int';
 $vartype['description'] = 'string';
@@ -290,8 +294,10 @@ $rememberme = $tikilib->get_preference('rememberme', 'disabled');
 if (($rememberme != 'disabled') 
 	and (isset($_COOKIE["$user_cookie_site"])) 
 	and (!isset($user) and !isset($_SESSION["$user_cookie_site"]))) {
-	$user = $userlib->get_user_by_hash($_COOKIE["$user_cookie_site"]);
-	$_SESSION["$user_cookie_site"] = $user;
+	$user = $userlib->get_user_by_cookie($_COOKIE["$user_cookie_site"]);
+	if ($user) {
+		$_SESSION["$user_cookie_site"] = $user;
+	}
 }
 
 // check what auth metod is selected. default is for the 'tiki' to auth users
@@ -355,54 +361,7 @@ if (isset($_REQUEST['highlight']) || (isset($feature_referer_highlight) && $feat
   $smarty->load_filter('output','highlight');
 }
 
-/** translate a English string
- * @param $content - English string
- * @param $lg - language - if not specify = global current language
- */
-function tra($content, $lg='') {
-    global $lang_use_db;
-    global $language;
 
-    if ($lang_use_db != 'y') {
-        if ($lg == "" || $lg == $language) {
-           global $lang;
-	      include_once("lang/$language/language.php");
-        }
-        else
-           include ("lang/$lg/language.php");
-        if ($content) {
-            if (isset($lang[$content])) {
-                return $lang[$content];
-            } else {
-                return $content;
-            }
-        }
-    } else {
-        global $tikilib;
-
-        $query = "select `tran` from `tiki_language` where `source`=? and `lang`=?";
-        $result = $tikilib->query($query, array($content,$lg == ""? $language: $lg));
-        $res = $result->fetchRow();
-
-        if (!$res)
-            return $content;
-
-        if (!isset($res["tran"])) {
-            global $record_untranslated;
-
-            if ($record_untranslated == 'y') {
-                $query = "insert into `tiki_untranslated` (`source`,`lang`) values (?,?)";
-
-                //No eror checking here
-                $tikilib->query($query, array($content,$language),-1,-1,false);
-            }
-
-            return $content;
-        }
-
-        return $res["tran"];
-    }
-}
 /* \brief  substr with a utf8 string - works only with $start and $length positive or nuls
  * This function is the same as substr but works with multibyte
  * In a multybyte sequence, the first byte of a multibyte sequence that represents a non-ASCII character is always in the range 0xC0 to 0xFD
@@ -607,6 +566,30 @@ if ($tiki_p_admin_quizzes == 'y') {
     }
 }
 
+if ($tiki_p_admin_calendar == 'y') {
+    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'calendar');
+
+    foreach ($perms["data"] as $perm) {
+        $perm = $perm["permName"];
+
+        $smarty->assign("$perm", 'y');
+        $$perm = 'y';
+    }
+}
+
+
+if ($tiki_p_admin_sheet == 'y') {
+    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'sheet');
+
+    foreach ($perms["data"] as $perm) {
+        $perm = $perm["permName"];
+
+        $smarty->assign("$perm", 'y');
+        $$perm = 'y';
+    }
+}
+
+
 if ($tiki_p_admin_cms == 'y') {
     $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'cms');
 
@@ -617,6 +600,7 @@ if ($tiki_p_admin_cms == 'y') {
         $$perm = 'y';
     }
 
+
     $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'topics');
 
     foreach ($perms["data"] as $perm) {
