@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker.php,v 1.72.2.47 2006/11/11 23:09:24 sylvieg Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker.php,v 1.72.2.81 2007/10/03 12:47:13 sylvieg Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -10,7 +10,7 @@
 require_once('tiki-setup.php');
 
 include_once('lib/trackers/trackerlib.php');
-include_once('lib/notifications/notificationlib.php');
+global $notificationlib; include_once('lib/notifications/notificationlib.php');
 
 if ($feature_categories == 'y') {
 	global $categlib;
@@ -34,7 +34,6 @@ if (!isset($_REQUEST["trackerId"])) {
 	die;
 }
 
-$smarty->assign('trackerId', $_REQUEST["trackerId"]);
 $smarty->assign('individual', 'n');
 
 if ($userlib->object_has_one_permission($_REQUEST["trackerId"], 'tracker')) {
@@ -46,6 +45,9 @@ if ($userlib->object_has_one_permission($_REQUEST["trackerId"], 'tracker')) {
 			if ($userlib->object_has_permission($user, $_REQUEST["trackerId"], 'tracker', $permName)) {
 				$$permName = 'y';
 				$smarty->assign("$permName", 'y');
+				if ($permName == 'tiki_p_admin_trackers') {
+					$propagate = true;
+				}
 			} else {
 				$$permName = 'n';
 				$smarty->assign("$permName", 'n');
@@ -59,6 +61,11 @@ if ($userlib->object_has_one_permission($_REQUEST["trackerId"], 'tracker')) {
     	foreach ($perms_array as $perm => $value) {
     		$$perm = $value;
     	}
+		if ($tiki_p_view_categories == 'y' || $tiki_p_admin_categories == 'y') {
+			$tiki_p_view_categories = 'y';
+			$tiki_p_view_trackers = 'y';
+			$smarty->assign('tiki_p_view_trackers', 'y');
+		}
    	} else {
    		$is_categorized = FALSE;
    	}
@@ -73,11 +80,27 @@ if ($userlib->object_has_one_permission($_REQUEST["trackerId"], 'tracker')) {
 		die;
 	}
 }
+if (!empty($propagate) && $propagate) { // if local set of tiki_p_admin_trackers, need to other perm
+    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'trackers');
+    foreach ($perms['data'] as $perm) {
+        $perm = $perm['permName'];
+        $smarty->assign("$perm", 'y');
+        $$perm = 'y';
+    }
+}
 
-if (!($tiki_p_view_trackers == 'y' || $tiki_p_admin == 'y' || $tiki_p_admin_trackers == 'y') && $tiki_p_create_tracker_items  == 'y')
-	$cookietab = "2";
-else
-	$cookietab = "1";
+if (!empty($_REQUEST['show']) && $_REQUEST['show'] == 'view') {
+	$cookietab = '1';
+} elseif (!empty($_REQUEST['show']) && $_REQUEST['show'] == 'mod') {
+	$cookietab = '2';
+} elseif (empty($_REQUEST['cookietab'])) {
+	if (!($tiki_p_view_trackers == 'y' || $tiki_p_admin == 'y' || $tiki_p_admin_trackers == 'y') && $tiki_p_create_tracker_items  == 'y')
+		$cookietab = "2";
+	else
+		$cookietab = "1";
+} else {
+	$cookietab = $_REQUEST['cookietab'];
+}
 $defaultvalues = array();
 
 if (isset($_REQUEST['vals']) and is_array($_REQUEST['vals'])) {
@@ -166,14 +189,17 @@ if (count($status_types) == 0) {
 	$tracker_info["showStatus"] = 'n';
 }
 
-$smarty->assign('tracker_info', $tracker_info);
-
 $xfields = $trklib->list_tracker_fields($_REQUEST["trackerId"], 0, -1, 'position_asc', '');
+if (!empty($tracker_info['showPopup'])) {
+	$popupFields = explode(',', $tracker_info['showPopup']);
+	$smarty->assign_by_ref('popupFields', $popupFields);
+} else {
+	$popupFields = array();
+}
 
 $writerfield = '';
 $writergroupfield = '';
 $mainfield = '';
-$mainfieldId = 0;
 $orderkey = false;
 $listfields = array();
 
@@ -193,17 +219,12 @@ for ($i = 0; $i < $temp_max; $i++) {
 	$filter_id = 'filter_' . $fid;
 	$xfields["data"][$i]["filter_id"] = $filter_id;
 	
-	if (!isset($mainfield) and $xfields["data"][$i]['isMain'] == 'y') {
-		$mainfield = $xfields["data"][$i]["name"];
-		$mainfieldId = $fid;
-	}
-
-	if (isset($tracker_info['defaultOrderKey']) and $tracker_info['defaultOrderKey'] == $xfields["data"][$i]['fieldId']) {
+	if (!empty($tracker_info['defaultOrderKey']) and $tracker_info['defaultOrderKey'] == $xfields["data"][$i]['fieldId']) {
 		$orderkey = true;
 	}
-	if (($xfields["data"][$i]['isTblVisible'] == 'y' or $xfields["data"][$i]['isSearchable'] == 'y') 
+	if (($xfields["data"][$i]['isTblVisible'] == 'y' or $xfields["data"][$i]['isSearchable'] == 'y' or in_array($fid, $popupFields)) 
 //		and ($xfields["data"][$i]['isPublic'] == 'y' or $tiki_p_admin_trackers == 'y') ispublic is for tracker plugin not normal view
-		and ($xfields["data"][$i]['isHidden'] == 'n' or $tiki_p_admin_trackers == 'y')
+		and ($xfields["data"][$i]['isHidden'] == 'n' or $xfields["data"][$i]['isHidden'] == '-' or $tiki_p_admin_trackers == 'y')
 		) {
 		
 		$listfields[$fid]['type'] = $xfields["data"][$i]["type"];
@@ -222,15 +243,16 @@ for ($i = 0; $i < $temp_max; $i++) {
 
 	}
 
-	if ($xfields["data"][$i]['isHidden'] == 'n' or $tiki_p_admin_trackers == 'y') {
+	if (($xfields["data"][$i]['isHidden'] == 'n' or $xfields["data"][$i]['isHidden'] == '-') or $tiki_p_admin_trackers == 'y') {
 		$ins_fields["data"][$i] = $xfields["data"][$i];
 		$fields["data"][$i] = $xfields["data"][$i];
 		if ($fields["data"][$i]["type"] == 'f') { // date and time
 			$fields["data"][$i]["value"] = '';
 			$ins_fields["data"][$i]["value"] = '';
 			if (isset($_REQUEST["$ins_id" . "Day"])) {
-				$ins_fields["data"][$i]["value"] = mktime($_REQUEST["$ins_id" . "Hour"], $_REQUEST["$ins_id" . "Minute"],
-				0, $_REQUEST["$ins_id" . "Month"], $_REQUEST["$ins_id" . "Day"], $_REQUEST["$ins_id" . "Year"]);
+				$dc = $tikilib->get_date_converter($user);
+				$ins_fields["data"][$i]["value"] = $dc->getServerDateFromDisplayDate(mktime($_REQUEST["$ins_id" . "Hour"], $_REQUEST["$ins_id" . "Minute"],
+				0, $_REQUEST["$ins_id" . "Month"], $_REQUEST["$ins_id" . "Day"], $_REQUEST["$ins_id" . "Year"]));
 			} else {
 				$ins_fields["data"][$i]["value"] = date("U");
 			}
@@ -302,7 +324,11 @@ for ($i = 0; $i < $temp_max; $i++) {
 		} elseif ($fields["data"][$i]["type"] == 'a') { // textarea
 			if (isset($_REQUEST["$ins_id"])) {
 				if (isset($fields["data"][$i]["options_array"][3]) and $fields["data"][$i]["options_array"][3] > 0 and strlen($_REQUEST["$ins_id"]) > $fields["data"][$i]["options_array"][3]) {
-					$ins_fields["data"][$i]["value"] = substr($_REQUEST["$ins_id"],0,$fields["data"][$i]["options_array"][3])." (...)";
+					if (function_exists('mb_substr')) {
+						$ins_fields["data"][$i]["value"] = mb_substr($_REQUEST["$ins_id"],0,$fields["data"][$i]["options_array"][3])." (...)";
+					} else {
+						$ins_fields["data"][$i]["value"] = substr($_REQUEST["$ins_id"],0,$fields["data"][$i]["options_array"][3])." (...)";
+					}
 				} else {
 					$ins_fields["data"][$i]["value"] = $_REQUEST["$ins_id"];
 				}
@@ -352,6 +378,9 @@ for ($i = 0; $i < $temp_max; $i++) {
 			} else {
 				$ins_fields["data"][$i]["value"] = '';
 			}
+			if ($fields['data'][$i]['type'] == 'D' && !empty($_REQUEST[$ins_id.'_other'])) { // drop down with other
+				$ins_fields['data'][$i]['value'] = $_REQUEST[$ins_id.'_other'];
+			}
 			if (isset($_REQUEST["$filter_id"])) {
 				$fields["data"][$i]["value"] = $_REQUEST["$filter_id"];
 			} else {
@@ -359,7 +388,7 @@ for ($i = 0; $i < $temp_max; $i++) {
 			}
 			if ($fields["data"][$i]["type"] == 'r')	{ // item link
 				if ($tiki_p_admin_trackers == 'y') {
-					$stt = 'poc';
+					$stt = 'opc';
 				} else {
 					$stt = 'o';
 				}
@@ -388,10 +417,7 @@ for ($i = 0; $i < $temp_max; $i++) {
 					}
 					fclose ($fp);
 					$ins_fields["data"][$i]["value"] = $data;
-					if (function_exists('mime_content_type'))
-						$ins_fields["data"][$i]["file_type"] = mime_content_type( $_FILES["$ins_id"]['tmp_name'] );
-					else
-						$ins_fields["data"][$i]["file_type"] = $_FILES["$ins_id"]['type'];
+					$ins_fields['data'][$i]['file_type'] = $_FILES["$ins_id"]['type'];
 					//$ins_fields["data"][$i]["value"] = $_FILES["$ins_id"]['name'];
 					$ins_fields["data"][$i]["file_size"] = $_FILES["$ins_id"]['size'];
 					$ins_fields["data"][$i]["file_name"] = $_FILES["$ins_id"]['name'];
@@ -401,12 +427,13 @@ for ($i = 0; $i < $temp_max; $i++) {
 	}
 	// store values to have them available when there is 
 	// an error in the values typed by an user for a field type.
-	$fields['data'][$i]['value'] = isset($ins_fields['data'][$i]['value'])?$ins_fields['data'][$i]['value']: '';
-	
+	if (isset( $fields['data'][$i]['fieldId']))
+		$fields['data'][$i]['value'] = isset($ins_fields['data'][$i]['value'])?$ins_fields['data'][$i]['value']: '';
+
+	if (empty($mainfield) and isset($fields['data'][$i]['isMain']) && $fields["data"][$i]["isMain"] == 'y' and !empty($fields["data"][$i]["value"])) {
+		$mainfield = $fields["data"][$i]["value"];
 }
-if (!isset($mainfield) and isset($fields["data"][0]["fieldId"]) and isset($fields["data"][0]["value"])) {
-	$mainfield = $fields["data"][0]["value"];
-	$mainfieldId = $fields["data"][0]["fieldId"];
+	
 }
 if ($textarea_options) {
 	include_once ('lib/quicktags/quicktagslib.php');
@@ -445,9 +472,9 @@ if ($user) {
 	$user_email = $userlib->get_user_email($user);
 	$emails = $notificationlib->get_mail_events('tracker_modified', $_REQUEST["trackerId"]);
 	if (in_array($user_email, $emails)) {
-		$smarty->assign('email_mon', tra('Cancel monitoring'));
+		$smarty->assign('email_mon', 'Cancel monitoring');
 	} else {
-		$smarty->assign('email_mon', tra('Monitor'));
+		$smarty->assign('email_mon', 'Monitor');
 	}
 }
 
@@ -483,6 +510,11 @@ if (isset($_REQUEST['import'])) {
 			$smarty->assign('input_err', '0'); // no warning to display
 
 			check_ticket('view-trackers');
+			if (empty($user) && $feature_antibot == 'y' && (!isset($_SESSION['random_number']) || $_SESSION['random_number'] != $_REQUEST['antibotcode'])) {
+				$smarty->assign('msg',tra("You have mistyped the anti-bot verification code; please try again."));
+				$smarty->display("error.tpl");
+				die;
+			}
 			if (!isset($_REQUEST["status"]) or ($tracker_info["showStatus"] != 'y' and $tiki_p_admin_trackers != 'y')) {
 				$_REQUEST["status"] = '';
 			}
@@ -498,6 +530,9 @@ if (isset($_REQUEST['import'])) {
 				header("location: tiki-view_tracker_item.php?trackerId=".$_REQUEST["trackerId"]."&itemId=".$itemid);
 				die;
 			}
+			if (isset($tracker_info["defaultStatus"])) {
+				$_REQUEST['status'] = $tracker_info["defaultStatus"];
+			}
 		}
 		else {
 			$cookietab = "2";
@@ -506,15 +541,25 @@ if (isset($_REQUEST['import'])) {
 	}
 }
 
-$smarty->assign_by_ref('fields', $fields["data"]);
-
 if (!isset($_REQUEST["sort_mode"])) {
-	if ($orderkey) {
-		$sort_mode = 'f_'.$tracker_info['defaultOrderKey'];
-		if (isset($tracker_info['defaultOrderDir'])) {
-			$sort_mode.= "_".$tracker_info['defaultOrderDir'];
+	if (isset($tracker_info['defaultOrderKey'])) {
+		if ($tracker_info['defaultOrderKey'] == -1)
+			$sort_mode = 'lastModif';
+		elseif ($tracker_info['defaultOrderKey'] == -2)
+			$sort_mode = 'created';
+		elseif ($orderkey) {
+			$sort_mode = 'f_'.$tracker_info['defaultOrderKey'];
 		} else {
-			$sort_mode.= "_asc";
+			$sort_mode = 'lastModif';
+		}
+		if (!empty($sort_mode)) {
+			if (isset($tracker_info['defaultOrderDir'])) {
+				$sort_mode.= "_".$tracker_info['defaultOrderDir'];
+			} else {
+				$sort_mode.= "_asc";
+			}
+		} else {
+			$sort_mode = '';
 		}
 	} else {
 		$sort_mode = '';
@@ -523,7 +568,7 @@ if (!isset($_REQUEST["sort_mode"])) {
 	$sort_mode = $_REQUEST["sort_mode"];
 }
 $sorts = split('_',$sort_mode);
-if (is_array($sorts) and isset($sorts[1]) and isset($listfields["{$sorts[1]}"]['type']) and $listfields["{$sorts[1]}"]['type'] == 'n') {
+if (is_array($sorts) and isset($sorts[1]) and isset($listfields["{$sorts[1]}"]['type']) and ($listfields["{$sorts[1]}"]['type'] == 'n' or $listfields["{$sorts[1]}"]['type'] == 'q')) {
 	$numsort = true;
 } else {
 	$numsort = false;
@@ -535,9 +580,13 @@ if (!isset($_REQUEST["offset"])) {
 } else {
 	$offset = $_REQUEST["offset"];
 }
-
 $smarty->assign_by_ref('offset', $offset);
 
+if (!empty($_REQUEST["maxRecords"])) {
+	$maxRecords = $_REQUEST['maxRecords'];
+	$smarty->assign('maxRecords', $maxRecords);
+}
+
 if (isset($_REQUEST["initial"])) {
 	$initial = $_REQUEST["initial"];
 } else {
@@ -545,6 +594,10 @@ if (isset($_REQUEST["initial"])) {
 }
 $smarty->assign('initial', $initial);
 $smarty->assign('initials', split(' ','a b c d e f g h i j k l m n o p q r s t u v w x y z'));
+if (empty($_REQUEST['initialFieldId'])) {
+	$_REQUEST['initialFieldId'] = $trklib->get_initial_field($listfields, $sort_mode);
+}
+$smarty->assign('initialFieldId', $_REQUEST['initialFieldId']);
 
 if ($my and $writerfield) {
 	$filterfield = $writerfield;
@@ -575,14 +628,14 @@ if ($my and $writerfield) {
 	} else {
 		$filtervalue = '';
 	}
+	if (isset($_REQUEST['filtervalue_other'])) {
+		$filtervalue = $_REQUEST['filtervalue_other'];
+	}
 	$exactvalue = '';
 }
 $smarty->assign('filtervalue', $filtervalue);
 
 
-if (!isset($_REQUEST["status"]))
-	$_REQUEST["status"] = 'o';
-
 $smarty->assign('status', $_REQUEST["status"]);
 
 // this isn't too beautiful, but works and doesn't break anything existing - amette
@@ -596,7 +649,7 @@ if (isset($tracker_info['useRatings']) and $tracker_info['useRatings'] == 'y'
 	$trklib->replace_rating($trackerId,$rate_itemId,$_REQUEST['fieldId'],$user,$_REQUEST["rate_$trackerId"]);
 }
 
-$items = $trklib->list_items($_REQUEST["trackerId"], $offset, $maxRecords, $sort_mode, $listfields, $filterfield, $filtervalue, $_REQUEST["status"],$initial,$exactvalue,$numsort);
+$items = $trklib->list_items($_REQUEST["trackerId"], $offset, $maxRecords, $sort_mode, $listfields, $filterfield, $filtervalue, $_REQUEST["status"],$initial,$exactvalue,$numsort, $_REQUEST['initialFieldId']);
 //var_dump($_REQUEST["trackerId"], $offset, $maxRecords, $sort_mode, $listfields, $filterfield, $filtervalue, $_REQUEST["status"],$initial,$exactvalue,$numsort);
 //die;
 //var_dump($items);die();
@@ -615,9 +668,14 @@ if (is_array($filtervalue)) {
 	$urlquery["filtervalue[".$filterfield."]"] = $filtervalue;
 }
 $smarty->assign_by_ref('urlquery', $urlquery);
-$cant = $items["cant"];
+$cant = $items['cant'];
 include "tiki-pagination.php";
 
+if ($tracker_info['useComments'] == 'y' && $tracker_info['showComments'] == 'y') {
+	foreach ($items['data'] as $itkey=>$oneitem) {
+		$items['data'][$itkey]['comments'] = $trklib->get_item_nb_comments($items['data'][$itkey]['itemId']);
+	}
+}
 if ($tracker_info['useAttachments'] == 'y' && $tracker_info['showAttachments'] == 'y') {
 	foreach ($items["data"] as $itkey=>$oneitem) {
 		$res = $trklib->get_item_nb_attachments($items["data"][$itkey]['itemId']);
@@ -636,7 +694,10 @@ foreach ($items["data"] as $itkey=>$oneitem) {
     }
 }
 ******************** */
-
+$smarty->assign('trackerId', $_REQUEST["trackerId"]);
+$smarty->assign('tracker_info', $tracker_info);
+if (isset($fields['data']))
+	$smarty->assign('fields', $fields['data']);
 $smarty->assign_by_ref('items', $items["data"]);
 $smarty->assign_by_ref('item_count', $items['cant']);
 $smarty->assign_by_ref('listfields', $listfields);
@@ -654,7 +715,7 @@ if ($feature_jscalendar) {
 	$smarty->assign('uses_jscalendar', 'y');
 }
 $smarty->assign('show_filters', 'n');
-if(count($fields['data'])>0) {
+if (isset($fields['data']) && count($fields['data'])>0) {
 foreach ($fields['data'] as $it) {
 	if ($it['isSearchable'] == 'y' and $it['isTblVisible'] == 'y'){
 		$smarty->assign('show_filters', 'y');
@@ -662,6 +723,7 @@ foreach ($fields['data'] as $it) {
 	}
 }
 }
+
 if ($items['data']) {
 	foreach ($items['data'] as $f=>$v) {
 		$items['data'][$f]['my_rate'] = $tikilib->get_user_vote("tracker.".$_REQUEST["trackerId"].'.'.$items['data'][$f]['itemId'],$user);
