@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker_item.php,v 1.69.2.83 2006/11/02 14:35:45 sylvieg Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker_item.php,v 1.69.2.101 2007/08/14 23:59:07 luciash Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -18,7 +18,7 @@ if ($feature_trackers != 'y') {
 	die;
 }
 
-$smarty->assign('special',false);
+$special = false;
 
 if (!isset($_REQUEST['trackerId']) && $userTracker == 'y') {
 	if (isset($_REQUEST['view']) and $_REQUEST['view'] == ' user') {
@@ -46,7 +46,7 @@ if (!isset($_REQUEST['trackerId']) && $userTracker == 'y') {
 				}
 				$_REQUEST['itemId'] = $trklib->replace_item($_REQUEST["trackerId"], 0, $addit, 'o');
 			}
-			$smarty->assign('special',' user');
+			$special = 'user';
 		}
 	} elseif (isset($_REQUEST["usertracker"]) and $tiki_p_admin == 'y') {
 		$thatgroup = $userlib->get_user_default_group($_REQUEST["usertracker"]);
@@ -68,7 +68,7 @@ if (!isset($_REQUEST['trackerId']) && $groupTracker == 'y') {
 				$addit['data'][0]['value'] = $group;
 				$_REQUEST['itemId'] = $trklib->replace_item($_REQUEST["trackerId"], 0, $addit, 'o');
 			}
-			$smarty->assign('special',' group');
+			$special = 'group';
 		}
 	} elseif (isset($_REQUEST["grouptracker"]) and $tiki_p_admin == 'y') {
 		$gtid = $userlib->get_grouptrackerid($_REQUEST["grouptracker"]);
@@ -76,6 +76,8 @@ if (!isset($_REQUEST['trackerId']) && $groupTracker == 'y') {
 		$_REQUEST["itemId"] = $trklib->get_item_id($_REQUEST['trackerId'],$gtid['groupFieldId'],$_REQUEST["grouptracker"]);
 	}
 }
+$smarty->assign_by_ref('special', $special);
+
 if ((!isset($_REQUEST["trackerId"]) || !$_REQUEST["trackerId"]) && isset($_REQUEST["itemId"])) {
 	$item_info = $trklib->get_tracker_item($_REQUEST["itemId"]);
 	$_REQUEST['trackerId'] = $item_info['trackerId'];	
@@ -86,8 +88,6 @@ if (!isset($_REQUEST["trackerId"]) || !$_REQUEST["trackerId"]) {
 	die;
 }
 
-$smarty->assign('trackerId', $_REQUEST["trackerId"]);
-
 if (!isset($utid) and !isset($gtid) and (!isset($_REQUEST["itemId"]) or !$_REQUEST["itemId"])) {
 	$smarty->assign('msg', tra("No item indicated"));
 	$smarty->display("error.tpl");
@@ -168,6 +168,9 @@ if ($userlib->object_has_one_permission($_REQUEST["trackerId"], 'tracker')) {
 			if ($userlib->object_has_permission($user, $_REQUEST["trackerId"], 'tracker', $permName)) {
 				$$permName = 'y';
 				$smarty->assign("$permName", 'y');
+				if ($permName == 'tiki_p_admin_trackers') {
+					$propagate = true;
+				}
 			} else {
 				$$permName = 'n';
 				$smarty->assign("$permName", 'n');
@@ -175,11 +178,18 @@ if ($userlib->object_has_one_permission($_REQUEST["trackerId"], 'tracker')) {
 		}
 	}
 }
+if (!empty($propagate) && $propagate) { // if local set of tiki_p_admin_trackers, need to other perm
+    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'trackers');
+    foreach ($perms['data'] as $perm) {
+        $perm = $perm['permName'];
+        $smarty->assign("$perm", 'y');
+        $$perm = 'y';
+    }
+}
 
 $tracker_info = $trklib->get_tracker($_REQUEST["trackerId"]);
 if ($t = $trklib->get_tracker_options($_REQUEST["trackerId"]))
 	$tracker_info = array_merge($tracker_info,$t);
-$smarty->assign('tracker_info', $tracker_info);
 if (!isset($tracker_info["writerCanModify"]) or (isset($utid) and ($_REQUEST['trackerId'] != $utid['usersTrackerId']))) {
 	$tracker_info["writerCanModify"] = 'n';
 }
@@ -187,7 +197,7 @@ if (!isset($tracker_info["writerGroupCanModify"]) or (isset($gtid) and ($_REQUES
 	$tracker_info["writerGroupCanModify"] = 'n';
 }
 
-if ($tiki_p_view_trackers != 'y' and $tracker_info["writerCanModify"] != 'y' and $tracker_info["writerGroupCanModify"] != 'y') {
+if ($tiki_p_view_trackers != 'y' and $tracker_info["writerCanModify"] != 'y' and $tracker_info["writerGroupCanModify"] != 'y'&& !$special) {
   if (!$user) {
     $smarty->assign('msg',$smarty->fetch('modules/mod-login_box.tpl'));
     $smarty->assign('errortitle',tra("Please login"));
@@ -208,7 +218,7 @@ $ins_fields = array();
 $usecategs = false;
 $ins_categs = array();
 $textarea_options = false;
-
+$tabi = 1;
 
 foreach($xfields["data"] as $i=>$array) {
 	$fid = $xfields["data"][$i]["fieldId"];
@@ -235,8 +245,8 @@ foreach($xfields["data"] as $i=>$array) {
 			$fields["data"][$i]["value"] = '';
 			$ins_fields["data"][$i]["value"] = '';
 			if (isset($_REQUEST["$ins_id" . "Day"])) {
-				$ins_fields["data"][$i]["value"] = mktime($_REQUEST["$ins_id" . "Hour"], $_REQUEST["$ins_id" . "Minute"],
-				0, $_REQUEST["$ins_id" . "Month"], $_REQUEST["$ins_id" . "Day"], $_REQUEST["$ins_id" . "Year"]);
+				$dc = $tikilib->get_date_converter($user);
+				$ins_fields["data"][$i]["value"] = $dc->getServerDateFromDisplayDate(mktime($_REQUEST["$ins_id" . "Hour"], $_REQUEST["$ins_id" . "Minute"], 0, $_REQUEST["$ins_id" . "Month"], $_REQUEST["$ins_id" . "Day"], $_REQUEST["$ins_id" . "Year"]));
 			} else {
 				$ins_fields["data"][$i]["value"] = date("U");
 			}
@@ -308,7 +318,11 @@ foreach($xfields["data"] as $i=>$array) {
 		} elseif ($fields["data"][$i]["type"] == 'a' and isset($fields["data"][$i]["options_array"][2]))	{
 			if (isset($_REQUEST["$ins_id"])) {
 				if (isset($fields["data"][$i]["options_array"][3]) and $fields["data"][$i]["options_array"][3] > 0 and strlen($_REQUEST["$ins_id"]) > $fields["data"][$i]["options_array"][3]) {
-					$ins_fields["data"][$i]["value"] = substr($_REQUEST["$ins_id"],0,$fields["data"][$i]["options_array"][3])." (...)";
+					if (function_exists('mb_substr')) {
+						$ins_fields["data"][$i]["value"] = mb_substr($_REQUEST["$ins_id"],0,$fields["data"][$i]["options_array"][3])." (...)";
+					} else {
+						$ins_fields["data"][$i]["value"] = substr($_REQUEST["$ins_id"],0,$fields["data"][$i]["options_array"][3])." (...)";
+					}
 				} else {
 					$ins_fields["data"][$i]["value"] = $_REQUEST["$ins_id"];
 				}
@@ -349,6 +363,9 @@ foreach($xfields["data"] as $i=>$array) {
 			} else {
 				$ins_fields["data"][$i]["value"] = '';
 			}
+			if ($ins_fields['data'][$i]['type'] == 'D' && !empty($_REQUEST[$ins_id.'_other'])) { // drop down with other
+				$ins_fields['data'][$i]['value'] = $_REQUEST[$ins_id.'_other'];
+			}
 			if (isset($_REQUEST["$filter_id"])) {
 				$fields["data"][$i]["value"] = $_REQUEST["$filter_id"];
 			} else {
@@ -421,7 +438,7 @@ if (isset($tracker_info["authorfield"])) {
 		$smarty->assign("tiki_p_view_trackers","y");
 	}
 }
-if ($tiki_p_view_trackers != 'y') {
+if ($tiki_p_view_trackers != 'y' && !$special) {
 	$smarty->assign('msg', tra("You do not have permission to use this feature"));
 	$smarty->display("error.tpl");
 	die;
@@ -444,7 +461,7 @@ if ($tiki_p_admin_trackers == 'y') {
 	}
 }
 
-if ($tiki_p_modify_tracker_items == 'y') {
+if ($tiki_p_modify_tracker_items == 'y' || $special) {
 	if (isset($_REQUEST["save"]) || isset($_REQUEST["save_return"])) {
 
 		// Check field values for each type and presence of mandatory ones
@@ -493,7 +510,7 @@ if ($tiki_p_modify_tracker_items == 'y') {
 		}
 		else {
 			$error = $ins_fields;
-			$cookietab = "2";
+			$tabi = "2";
 			$smarty->assign('input_err', '1'); // warning to display
 
 			// can't go back if there are errors
@@ -538,9 +555,9 @@ if (isset($tracker_info['useRatings']) and $tracker_info['useRatings'] == 'y' an
 if ($_REQUEST["itemId"]) {
 	$info = $trklib->get_tracker_item($_REQUEST["itemId"]);
 	if (!isset($info['trackerId'])) $info['trackerId'] = $_REQUEST['trackerId'];
-	if ((isset($info['status']) and $info['status'] == 'p' && $tiki_p_view_trackers_pending != 'y') 
-	||  (isset($info['status']) and $info['status'] == 'c' && $tiki_p_view_trackers_closed != 'y')
-	||  (!$tikilib->user_has_perm_on_object($user, $info['trackerId'], 'tracker', 'tiki_p_view_trackers') &&
+	if ((isset($info['status']) and $info['status'] == 'p' && !$tikilib->user_has_perm_on_object($user, $info['trackerId'], 'tracker', 'tiki_p_view_trackers_pending')) 
+	||  (isset($info['status']) and $info['status'] == 'c' && !$tikilib->user_has_perm_on_object($user, $info['trackerId'], 'tracker', 'tiki_p_view_trackers_closed'))
+	||  ($tiki_p_admin_trackers != 'y' && !$tikilib->user_has_perm_on_object($user, $info['trackerId'], 'tracker', 'tiki_p_view_trackers') &&
 	  (!isset($utid) || $_REQUEST['trackerId'] != $utid['usersTrackerId']) &&
 		(!isset($gtid) || $_REQUEST['trackerId'] != $utid['groupTrackerId'])
 	) ) {
@@ -563,14 +580,20 @@ if ($_REQUEST["itemId"]) {
 					if (!isset($info["$fid"])) $info["$fid"] = '';
 				}
 				if ($fields["data"][$i]["type"] == 'e') {
-					include_once('lib/categories/categlib.php');
+					global $categlib; include_once('lib/categories/categlib.php');
 					$k = $fields["data"][$i]["options"];
 					$ins_fields["data"][$i]["$k"] = $categlib->get_child_categories($k);
 					if (!isset($cat)) {
 						$cat = $categlib->get_object_categories("tracker ".$_REQUEST["trackerId"],$_REQUEST["itemId"]);
 					}
-					foreach ($cat as $c) {
-						$ins_fields["data"][$i]["cat"]["$c"] = 'y';
+					if (isset($_REQUEST['save']) || isset($_REQUEST['save_return'])) {
+						foreach ($ins_categs as $c) {
+							$ins_fields['data'][$i]['cat']["$c"] = 'y';
+						}
+					} else {
+						foreach ($cat as $c) {
+							$ins_fields['data'][$i]['cat']["$c"] = 'y';
+						}
 					}
 				} elseif ($fields["data"][$i]["type"] == 'l') {
 					if (isset($fields["data"][$i]["options_array"][3])) {
@@ -600,7 +623,12 @@ if ($_REQUEST["itemId"]) {
 				} elseif  ($fields["data"][$i]["type"] == 'r') {
 					$ins_fields["data"][$i]["linkId"] = $trklib->get_item_id($fields["data"][$i]["options_array"][0],$fields["data"][$i]["options_array"][1],$info[$fid]);
 					$ins_fields["data"][$i]["value"] = $info[$fid];
-					$ins_fields["data"][$i]["list"] = $trklib->get_all_items($fields["data"][$i]["options_array"][0],$fields["data"][$i]["options_array"][1]);
+					if ($tiki_p_admin_trackers == 'y') {
+						$stt = 'opc';
+					} else {
+						$stt = 'o';
+					}
+					$ins_fields["data"][$i]["list"] = $trklib->get_all_items($fields["data"][$i]["options_array"][0],$fields["data"][$i]["options_array"][1],$stt);
 				} elseif ($fields["data"][$i]["type"] == 'u') {
 					if ($fields["data"][$i]['options'] == 2 and !$info["$fid"]) {
 						$ins_fields["data"][$i]["defvalue"] = $user;
@@ -636,6 +664,7 @@ if ($_REQUEST["itemId"]) {
 				$smarty->assign('tracker_item_main_value', $ins_fields['data'][$i]['value']);			
 		}
 	}
+
 /* **************** seems it is only 1.8
 	for ($i = 0; $i < count($fields["data"]); $i++) {
 		$name = $fields["data"][$i]["name"];
@@ -653,9 +682,13 @@ if ($_REQUEST["itemId"]) {
 //restore types values if there is an error
 if(isset($error)) {
 	foreach($ins_fields["data"] as $i=>$array) {
-		$ins_fields["data"][$i]["value"] = $error["data"][$i]["value"];
+		if (isset($error["data"][$i]["value"])) {
+			$ins_fields["data"][$i]["value"] = $error["data"][$i]["value"];
+		}
 	}
 }	
+$smarty->assign('trackerId', $_REQUEST["trackerId"]);
+$smarty->assign('tracker_info', $tracker_info);
 $smarty->assign_by_ref('info', $info);
 $smarty->assign_by_ref('fields', $fields["data"]);
 $smarty->assign_by_ref('ins_fields', $ins_fields["data"]);
@@ -706,6 +739,7 @@ if ($tracker_info["useComments"] == 'y') {
 		$comment_info = $trklib->get_item_comment($_REQUEST["commentId"]);
 		$smarty->assign('comment_title', $comment_info["title"]);
 		$smarty->assign('comment_data', $comment_info["data"]);
+		$tabi = 2;
 	} else {
 		$_REQUEST["commentId"] = 0;
 		$smarty->assign('comment_title', '');
@@ -718,6 +752,11 @@ if ($tracker_info["useComments"] == 'y') {
 	if ($tiki_p_comment_tracker_items == 'y') {
 		if (isset($_REQUEST["save_comment"])) {
 			check_ticket('view-trackers-items');
+			if (empty($user) && $feature_antibot == 'y' && (!isset($_SESSION['random_number']) || $_SESSION['random_number'] != $_REQUEST['antibotcode'])) {
+				$smarty->assign('msg',tra("You have mistyped the anti-bot verification code; please try again."));
+				$smarty->display("error.tpl");
+				die;
+			}
 			$trklib->replace_item_comment($_REQUEST["commentId"], $_REQUEST["itemId"], $_REQUEST["comment_title"], $_REQUEST["comment_data"], $user);
 			$smarty->assign('comment_title', '');
 			$smarty->assign('comment_data', '');
@@ -812,7 +851,6 @@ if ($tracker_info["useAttachments"] == 'y') {
 	$smarty->assign('attfields', $attfields);
 	$smarty->assign('attextra', $attextra);
 }
-$tabi = 1;
 if (isset($_REQUEST['show'])) {
 	if ($_REQUEST['show'] == 'view') {
 		$tabi = 1;
@@ -828,7 +866,7 @@ if (isset($_REQUEST['show'])) {
 	}
 }
 
-setcookie("tab","$tabi");
+setcookie("tab",$tabi);
 $smarty->assign('cookietab',$tabi);
 
 if (isset($_REQUEST['from'])) {
